# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import (
    Iterable as typing___Iterable,
    Optional as typing___Optional,
    Text as typing___Text,
)

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.containers import (
    RepeatedCompositeFieldContainer as google___protobuf___internal___containers___RepeatedCompositeFieldContainer,
)
from google.protobuf.message import Message as google___protobuf___message___Message
from google.protobuf.wrappers_pb2 import (
    BoolValue as google___protobuf___wrappers_pb2___BoolValue,
    DoubleValue as google___protobuf___wrappers_pb2___DoubleValue,
    Int64Value as google___protobuf___wrappers_pb2___Int64Value,
    StringValue as google___protobuf___wrappers_pb2___StringValue,
)
from typing_extensions import Literal as typing_extensions___Literal

from google.ads.google_ads.v3.proto.common.criteria_pb2 import (
    KeywordInfo as google___ads___googleads___v3___common___criteria_pb2___KeywordInfo,
)
from google.ads.google_ads.v3.proto.common.extensions_pb2 import (
    CallFeedItem as google___ads___googleads___v3___common___extensions_pb2___CallFeedItem,
    CalloutFeedItem as google___ads___googleads___v3___common___extensions_pb2___CalloutFeedItem,
    SitelinkFeedItem as google___ads___googleads___v3___common___extensions_pb2___SitelinkFeedItem,
)
from google.ads.google_ads.v3.proto.enums.keyword_match_type_pb2 import (
    KeywordMatchTypeEnum as google___ads___googleads___v3___enums___keyword_match_type_pb2___KeywordMatchTypeEnum,
)
from google.ads.google_ads.v3.proto.enums.recommendation_type_pb2 import (
    RecommendationTypeEnum as google___ads___googleads___v3___enums___recommendation_type_pb2___RecommendationTypeEnum,
)
from google.ads.google_ads.v3.proto.enums.target_cpa_opt_in_recommendation_goal_pb2 import (
    TargetCpaOptInRecommendationGoalEnum as google___ads___googleads___v3___enums___target_cpa_opt_in_recommendation_goal_pb2___TargetCpaOptInRecommendationGoalEnum,
)
from google.ads.google_ads.v3.proto.resources.ad_pb2 import (
    Ad as google___ads___googleads___v3___resources___ad_pb2___Ad,
)

builtin___bool = bool
builtin___bytes = bytes
builtin___float = float
builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class Recommendation(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    class RecommendationImpact(google___protobuf___message___Message):
        DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
        @property
        def base_metrics(self) -> type___Recommendation.RecommendationMetrics: ...
        @property
        def potential_metrics(self) -> type___Recommendation.RecommendationMetrics: ...
        def __init__(
            self,
            *,
            base_metrics: typing___Optional[
                type___Recommendation.RecommendationMetrics
            ] = None,
            potential_metrics: typing___Optional[
                type___Recommendation.RecommendationMetrics
            ] = None,
        ) -> None: ...
        def HasField(
            self,
            field_name: typing_extensions___Literal[
                "base_metrics",
                b"base_metrics",
                "potential_metrics",
                b"potential_metrics",
            ],
        ) -> builtin___bool: ...
        def ClearField(
            self,
            field_name: typing_extensions___Literal[
                "base_metrics",
                b"base_metrics",
                "potential_metrics",
                b"potential_metrics",
            ],
        ) -> None: ...
    type___RecommendationImpact = RecommendationImpact
    class RecommendationMetrics(google___protobuf___message___Message):
        DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
        @property
        def impressions(self) -> google___protobuf___wrappers_pb2___DoubleValue: ...
        @property
        def clicks(self) -> google___protobuf___wrappers_pb2___DoubleValue: ...
        @property
        def cost_micros(self) -> google___protobuf___wrappers_pb2___Int64Value: ...
        @property
        def conversions(self) -> google___protobuf___wrappers_pb2___DoubleValue: ...
        @property
        def video_views(self) -> google___protobuf___wrappers_pb2___DoubleValue: ...
        def __init__(
            self,
            *,
            impressions: typing___Optional[
                google___protobuf___wrappers_pb2___DoubleValue
            ] = None,
            clicks: typing___Optional[
                google___protobuf___wrappers_pb2___DoubleValue
            ] = None,
            cost_micros: typing___Optional[
                google___protobuf___wrappers_pb2___Int64Value
            ] = None,
            conversions: typing___Optional[
                google___protobuf___wrappers_pb2___DoubleValue
            ] = None,
            video_views: typing___Optional[
                google___protobuf___wrappers_pb2___DoubleValue
            ] = None,
        ) -> None: ...
        def HasField(
            self,
            field_name: typing_extensions___Literal[
                "clicks",
                b"clicks",
                "conversions",
                b"conversions",
                "cost_micros",
                b"cost_micros",
                "impressions",
                b"impressions",
                "video_views",
                b"video_views",
            ],
        ) -> builtin___bool: ...
        def ClearField(
            self,
            field_name: typing_extensions___Literal[
                "clicks",
                b"clicks",
                "conversions",
                b"conversions",
                "cost_micros",
                b"cost_micros",
                "impressions",
                b"impressions",
                "video_views",
                b"video_views",
            ],
        ) -> None: ...
    type___RecommendationMetrics = RecommendationMetrics
    class CampaignBudgetRecommendation(google___protobuf___message___Message):
        DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
        class CampaignBudgetRecommendationOption(google___protobuf___message___Message):
            DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
            @property
            def budget_amount_micros(
                self,
            ) -> google___protobuf___wrappers_pb2___Int64Value: ...
            @property
            def impact(self) -> type___Recommendation.RecommendationImpact: ...
            def __init__(
                self,
                *,
                budget_amount_micros: typing___Optional[
                    google___protobuf___wrappers_pb2___Int64Value
                ] = None,
                impact: typing___Optional[
                    type___Recommendation.RecommendationImpact
                ] = None,
            ) -> None: ...
            def HasField(
                self,
                field_name: typing_extensions___Literal[
                    "budget_amount_micros", b"budget_amount_micros", "impact", b"impact"
                ],
            ) -> builtin___bool: ...
            def ClearField(
                self,
                field_name: typing_extensions___Literal[
                    "budget_amount_micros", b"budget_amount_micros", "impact", b"impact"
                ],
            ) -> None: ...
        type___CampaignBudgetRecommendationOption = CampaignBudgetRecommendationOption
        @property
        def current_budget_amount_micros(
            self,
        ) -> google___protobuf___wrappers_pb2___Int64Value: ...
        @property
        def recommended_budget_amount_micros(
            self,
        ) -> google___protobuf___wrappers_pb2___Int64Value: ...
        @property
        def budget_options(
            self,
        ) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[
            type___Recommendation.CampaignBudgetRecommendation.CampaignBudgetRecommendationOption
        ]: ...
        def __init__(
            self,
            *,
            current_budget_amount_micros: typing___Optional[
                google___protobuf___wrappers_pb2___Int64Value
            ] = None,
            recommended_budget_amount_micros: typing___Optional[
                google___protobuf___wrappers_pb2___Int64Value
            ] = None,
            budget_options: typing___Optional[
                typing___Iterable[
                    type___Recommendation.CampaignBudgetRecommendation.CampaignBudgetRecommendationOption
                ]
            ] = None,
        ) -> None: ...
        def HasField(
            self,
            field_name: typing_extensions___Literal[
                "current_budget_amount_micros",
                b"current_budget_amount_micros",
                "recommended_budget_amount_micros",
                b"recommended_budget_amount_micros",
            ],
        ) -> builtin___bool: ...
        def ClearField(
            self,
            field_name: typing_extensions___Literal[
                "budget_options",
                b"budget_options",
                "current_budget_amount_micros",
                b"current_budget_amount_micros",
                "recommended_budget_amount_micros",
                b"recommended_budget_amount_micros",
            ],
        ) -> None: ...
    type___CampaignBudgetRecommendation = CampaignBudgetRecommendation
    class KeywordRecommendation(google___protobuf___message___Message):
        DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
        @property
        def keyword(
            self,
        ) -> google___ads___googleads___v3___common___criteria_pb2___KeywordInfo: ...
        @property
        def recommended_cpc_bid_micros(
            self,
        ) -> google___protobuf___wrappers_pb2___Int64Value: ...
        def __init__(
            self,
            *,
            keyword: typing___Optional[
                google___ads___googleads___v3___common___criteria_pb2___KeywordInfo
            ] = None,
            recommended_cpc_bid_micros: typing___Optional[
                google___protobuf___wrappers_pb2___Int64Value
            ] = None,
        ) -> None: ...
        def HasField(
            self,
            field_name: typing_extensions___Literal[
                "keyword",
                b"keyword",
                "recommended_cpc_bid_micros",
                b"recommended_cpc_bid_micros",
            ],
        ) -> builtin___bool: ...
        def ClearField(
            self,
            field_name: typing_extensions___Literal[
                "keyword",
                b"keyword",
                "recommended_cpc_bid_micros",
                b"recommended_cpc_bid_micros",
            ],
        ) -> None: ...
    type___KeywordRecommendation = KeywordRecommendation
    class MaximizeConversionsOptInRecommendation(google___protobuf___message___Message):
        DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
        @property
        def recommended_budget_amount_micros(
            self,
        ) -> google___protobuf___wrappers_pb2___Int64Value: ...
        def __init__(
            self,
            *,
            recommended_budget_amount_micros: typing___Optional[
                google___protobuf___wrappers_pb2___Int64Value
            ] = None,
        ) -> None: ...
        def HasField(
            self,
            field_name: typing_extensions___Literal[
                "recommended_budget_amount_micros", b"recommended_budget_amount_micros"
            ],
        ) -> builtin___bool: ...
        def ClearField(
            self,
            field_name: typing_extensions___Literal[
                "recommended_budget_amount_micros", b"recommended_budget_amount_micros"
            ],
        ) -> None: ...
    type___MaximizeConversionsOptInRecommendation = (
        MaximizeConversionsOptInRecommendation
    )
    class TextAdRecommendation(google___protobuf___message___Message):
        DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
        @property
        def ad(self) -> google___ads___googleads___v3___resources___ad_pb2___Ad: ...
        @property
        def creation_date(self) -> google___protobuf___wrappers_pb2___StringValue: ...
        @property
        def auto_apply_date(self) -> google___protobuf___wrappers_pb2___StringValue: ...
        def __init__(
            self,
            *,
            ad: typing___Optional[
                google___ads___googleads___v3___resources___ad_pb2___Ad
            ] = None,
            creation_date: typing___Optional[
                google___protobuf___wrappers_pb2___StringValue
            ] = None,
            auto_apply_date: typing___Optional[
                google___protobuf___wrappers_pb2___StringValue
            ] = None,
        ) -> None: ...
        def HasField(
            self,
            field_name: typing_extensions___Literal[
                "ad",
                b"ad",
                "auto_apply_date",
                b"auto_apply_date",
                "creation_date",
                b"creation_date",
            ],
        ) -> builtin___bool: ...
        def ClearField(
            self,
            field_name: typing_extensions___Literal[
                "ad",
                b"ad",
                "auto_apply_date",
                b"auto_apply_date",
                "creation_date",
                b"creation_date",
            ],
        ) -> None: ...
    type___TextAdRecommendation = TextAdRecommendation
    class MoveUnusedBudgetRecommendation(google___protobuf___message___Message):
        DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
        @property
        def excess_campaign_budget(
            self,
        ) -> google___protobuf___wrappers_pb2___StringValue: ...
        @property
        def budget_recommendation(
            self,
        ) -> type___Recommendation.CampaignBudgetRecommendation: ...
        def __init__(
            self,
            *,
            excess_campaign_budget: typing___Optional[
                google___protobuf___wrappers_pb2___StringValue
            ] = None,
            budget_recommendation: typing___Optional[
                type___Recommendation.CampaignBudgetRecommendation
            ] = None,
        ) -> None: ...
        def HasField(
            self,
            field_name: typing_extensions___Literal[
                "budget_recommendation",
                b"budget_recommendation",
                "excess_campaign_budget",
                b"excess_campaign_budget",
            ],
        ) -> builtin___bool: ...
        def ClearField(
            self,
            field_name: typing_extensions___Literal[
                "budget_recommendation",
                b"budget_recommendation",
                "excess_campaign_budget",
                b"excess_campaign_budget",
            ],
        ) -> None: ...
    type___MoveUnusedBudgetRecommendation = MoveUnusedBudgetRecommendation
    class TargetCpaOptInRecommendation(google___protobuf___message___Message):
        DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
        class TargetCpaOptInRecommendationOption(google___protobuf___message___Message):
            DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
            goal: google___ads___googleads___v3___enums___target_cpa_opt_in_recommendation_goal_pb2___TargetCpaOptInRecommendationGoalEnum.TargetCpaOptInRecommendationGoalValue = ...
            @property
            def target_cpa_micros(
                self,
            ) -> google___protobuf___wrappers_pb2___Int64Value: ...
            @property
            def required_campaign_budget_amount_micros(
                self,
            ) -> google___protobuf___wrappers_pb2___Int64Value: ...
            @property
            def impact(self) -> type___Recommendation.RecommendationImpact: ...
            def __init__(
                self,
                *,
                goal: typing___Optional[
                    google___ads___googleads___v3___enums___target_cpa_opt_in_recommendation_goal_pb2___TargetCpaOptInRecommendationGoalEnum.TargetCpaOptInRecommendationGoalValue
                ] = None,
                target_cpa_micros: typing___Optional[
                    google___protobuf___wrappers_pb2___Int64Value
                ] = None,
                required_campaign_budget_amount_micros: typing___Optional[
                    google___protobuf___wrappers_pb2___Int64Value
                ] = None,
                impact: typing___Optional[
                    type___Recommendation.RecommendationImpact
                ] = None,
            ) -> None: ...
            def HasField(
                self,
                field_name: typing_extensions___Literal[
                    "impact",
                    b"impact",
                    "required_campaign_budget_amount_micros",
                    b"required_campaign_budget_amount_micros",
                    "target_cpa_micros",
                    b"target_cpa_micros",
                ],
            ) -> builtin___bool: ...
            def ClearField(
                self,
                field_name: typing_extensions___Literal[
                    "goal",
                    b"goal",
                    "impact",
                    b"impact",
                    "required_campaign_budget_amount_micros",
                    b"required_campaign_budget_amount_micros",
                    "target_cpa_micros",
                    b"target_cpa_micros",
                ],
            ) -> None: ...
        type___TargetCpaOptInRecommendationOption = TargetCpaOptInRecommendationOption
        @property
        def options(
            self,
        ) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[
            type___Recommendation.TargetCpaOptInRecommendation.TargetCpaOptInRecommendationOption
        ]: ...
        @property
        def recommended_target_cpa_micros(
            self,
        ) -> google___protobuf___wrappers_pb2___Int64Value: ...
        def __init__(
            self,
            *,
            options: typing___Optional[
                typing___Iterable[
                    type___Recommendation.TargetCpaOptInRecommendation.TargetCpaOptInRecommendationOption
                ]
            ] = None,
            recommended_target_cpa_micros: typing___Optional[
                google___protobuf___wrappers_pb2___Int64Value
            ] = None,
        ) -> None: ...
        def HasField(
            self,
            field_name: typing_extensions___Literal[
                "recommended_target_cpa_micros", b"recommended_target_cpa_micros"
            ],
        ) -> builtin___bool: ...
        def ClearField(
            self,
            field_name: typing_extensions___Literal[
                "options",
                b"options",
                "recommended_target_cpa_micros",
                b"recommended_target_cpa_micros",
            ],
        ) -> None: ...
    type___TargetCpaOptInRecommendation = TargetCpaOptInRecommendation
    class SearchPartnersOptInRecommendation(google___protobuf___message___Message):
        DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
        def __init__(self,) -> None: ...
    type___SearchPartnersOptInRecommendation = SearchPartnersOptInRecommendation
    class EnhancedCpcOptInRecommendation(google___protobuf___message___Message):
        DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
        def __init__(self,) -> None: ...
    type___EnhancedCpcOptInRecommendation = EnhancedCpcOptInRecommendation
    class MaximizeClicksOptInRecommendation(google___protobuf___message___Message):
        DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
        @property
        def recommended_budget_amount_micros(
            self,
        ) -> google___protobuf___wrappers_pb2___Int64Value: ...
        def __init__(
            self,
            *,
            recommended_budget_amount_micros: typing___Optional[
                google___protobuf___wrappers_pb2___Int64Value
            ] = None,
        ) -> None: ...
        def HasField(
            self,
            field_name: typing_extensions___Literal[
                "recommended_budget_amount_micros", b"recommended_budget_amount_micros"
            ],
        ) -> builtin___bool: ...
        def ClearField(
            self,
            field_name: typing_extensions___Literal[
                "recommended_budget_amount_micros", b"recommended_budget_amount_micros"
            ],
        ) -> None: ...
    type___MaximizeClicksOptInRecommendation = MaximizeClicksOptInRecommendation
    class OptimizeAdRotationRecommendation(google___protobuf___message___Message):
        DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
        def __init__(self,) -> None: ...
    type___OptimizeAdRotationRecommendation = OptimizeAdRotationRecommendation
    class SitelinkExtensionRecommendation(google___protobuf___message___Message):
        DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
        @property
        def recommended_extensions(
            self,
        ) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[
            google___ads___googleads___v3___common___extensions_pb2___SitelinkFeedItem
        ]: ...
        def __init__(
            self,
            *,
            recommended_extensions: typing___Optional[
                typing___Iterable[
                    google___ads___googleads___v3___common___extensions_pb2___SitelinkFeedItem
                ]
            ] = None,
        ) -> None: ...
        def ClearField(
            self,
            field_name: typing_extensions___Literal[
                "recommended_extensions", b"recommended_extensions"
            ],
        ) -> None: ...
    type___SitelinkExtensionRecommendation = SitelinkExtensionRecommendation
    class CalloutExtensionRecommendation(google___protobuf___message___Message):
        DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
        @property
        def recommended_extensions(
            self,
        ) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[
            google___ads___googleads___v3___common___extensions_pb2___CalloutFeedItem
        ]: ...
        def __init__(
            self,
            *,
            recommended_extensions: typing___Optional[
                typing___Iterable[
                    google___ads___googleads___v3___common___extensions_pb2___CalloutFeedItem
                ]
            ] = None,
        ) -> None: ...
        def ClearField(
            self,
            field_name: typing_extensions___Literal[
                "recommended_extensions", b"recommended_extensions"
            ],
        ) -> None: ...
    type___CalloutExtensionRecommendation = CalloutExtensionRecommendation
    class CallExtensionRecommendation(google___protobuf___message___Message):
        DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
        @property
        def recommended_extensions(
            self,
        ) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[
            google___ads___googleads___v3___common___extensions_pb2___CallFeedItem
        ]: ...
        def __init__(
            self,
            *,
            recommended_extensions: typing___Optional[
                typing___Iterable[
                    google___ads___googleads___v3___common___extensions_pb2___CallFeedItem
                ]
            ] = None,
        ) -> None: ...
        def ClearField(
            self,
            field_name: typing_extensions___Literal[
                "recommended_extensions", b"recommended_extensions"
            ],
        ) -> None: ...
    type___CallExtensionRecommendation = CallExtensionRecommendation
    class KeywordMatchTypeRecommendation(google___protobuf___message___Message):
        DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
        recommended_match_type: google___ads___googleads___v3___enums___keyword_match_type_pb2___KeywordMatchTypeEnum.KeywordMatchTypeValue = ...
        @property
        def keyword(
            self,
        ) -> google___ads___googleads___v3___common___criteria_pb2___KeywordInfo: ...
        def __init__(
            self,
            *,
            keyword: typing___Optional[
                google___ads___googleads___v3___common___criteria_pb2___KeywordInfo
            ] = None,
            recommended_match_type: typing___Optional[
                google___ads___googleads___v3___enums___keyword_match_type_pb2___KeywordMatchTypeEnum.KeywordMatchTypeValue
            ] = None,
        ) -> None: ...
        def HasField(
            self, field_name: typing_extensions___Literal["keyword", b"keyword"]
        ) -> builtin___bool: ...
        def ClearField(
            self,
            field_name: typing_extensions___Literal[
                "keyword",
                b"keyword",
                "recommended_match_type",
                b"recommended_match_type",
            ],
        ) -> None: ...
    type___KeywordMatchTypeRecommendation = KeywordMatchTypeRecommendation

    resource_name: typing___Text = ...
    type: google___ads___googleads___v3___enums___recommendation_type_pb2___RecommendationTypeEnum.RecommendationTypeValue = ...
    @property
    def impact(self) -> type___Recommendation.RecommendationImpact: ...
    @property
    def campaign_budget(self) -> google___protobuf___wrappers_pb2___StringValue: ...
    @property
    def campaign(self) -> google___protobuf___wrappers_pb2___StringValue: ...
    @property
    def ad_group(self) -> google___protobuf___wrappers_pb2___StringValue: ...
    @property
    def dismissed(self) -> google___protobuf___wrappers_pb2___BoolValue: ...
    @property
    def campaign_budget_recommendation(
        self,
    ) -> type___Recommendation.CampaignBudgetRecommendation: ...
    @property
    def keyword_recommendation(self) -> type___Recommendation.KeywordRecommendation: ...
    @property
    def text_ad_recommendation(self) -> type___Recommendation.TextAdRecommendation: ...
    @property
    def target_cpa_opt_in_recommendation(
        self,
    ) -> type___Recommendation.TargetCpaOptInRecommendation: ...
    @property
    def maximize_conversions_opt_in_recommendation(
        self,
    ) -> type___Recommendation.MaximizeConversionsOptInRecommendation: ...
    @property
    def enhanced_cpc_opt_in_recommendation(
        self,
    ) -> type___Recommendation.EnhancedCpcOptInRecommendation: ...
    @property
    def search_partners_opt_in_recommendation(
        self,
    ) -> type___Recommendation.SearchPartnersOptInRecommendation: ...
    @property
    def maximize_clicks_opt_in_recommendation(
        self,
    ) -> type___Recommendation.MaximizeClicksOptInRecommendation: ...
    @property
    def optimize_ad_rotation_recommendation(
        self,
    ) -> type___Recommendation.OptimizeAdRotationRecommendation: ...
    @property
    def callout_extension_recommendation(
        self,
    ) -> type___Recommendation.CalloutExtensionRecommendation: ...
    @property
    def sitelink_extension_recommendation(
        self,
    ) -> type___Recommendation.SitelinkExtensionRecommendation: ...
    @property
    def call_extension_recommendation(
        self,
    ) -> type___Recommendation.CallExtensionRecommendation: ...
    @property
    def keyword_match_type_recommendation(
        self,
    ) -> type___Recommendation.KeywordMatchTypeRecommendation: ...
    @property
    def move_unused_budget_recommendation(
        self,
    ) -> type___Recommendation.MoveUnusedBudgetRecommendation: ...
    def __init__(
        self,
        *,
        resource_name: typing___Optional[typing___Text] = None,
        type: typing___Optional[
            google___ads___googleads___v3___enums___recommendation_type_pb2___RecommendationTypeEnum.RecommendationTypeValue
        ] = None,
        impact: typing___Optional[type___Recommendation.RecommendationImpact] = None,
        campaign_budget: typing___Optional[
            google___protobuf___wrappers_pb2___StringValue
        ] = None,
        campaign: typing___Optional[
            google___protobuf___wrappers_pb2___StringValue
        ] = None,
        ad_group: typing___Optional[
            google___protobuf___wrappers_pb2___StringValue
        ] = None,
        dismissed: typing___Optional[
            google___protobuf___wrappers_pb2___BoolValue
        ] = None,
        campaign_budget_recommendation: typing___Optional[
            type___Recommendation.CampaignBudgetRecommendation
        ] = None,
        keyword_recommendation: typing___Optional[
            type___Recommendation.KeywordRecommendation
        ] = None,
        text_ad_recommendation: typing___Optional[
            type___Recommendation.TextAdRecommendation
        ] = None,
        target_cpa_opt_in_recommendation: typing___Optional[
            type___Recommendation.TargetCpaOptInRecommendation
        ] = None,
        maximize_conversions_opt_in_recommendation: typing___Optional[
            type___Recommendation.MaximizeConversionsOptInRecommendation
        ] = None,
        enhanced_cpc_opt_in_recommendation: typing___Optional[
            type___Recommendation.EnhancedCpcOptInRecommendation
        ] = None,
        search_partners_opt_in_recommendation: typing___Optional[
            type___Recommendation.SearchPartnersOptInRecommendation
        ] = None,
        maximize_clicks_opt_in_recommendation: typing___Optional[
            type___Recommendation.MaximizeClicksOptInRecommendation
        ] = None,
        optimize_ad_rotation_recommendation: typing___Optional[
            type___Recommendation.OptimizeAdRotationRecommendation
        ] = None,
        callout_extension_recommendation: typing___Optional[
            type___Recommendation.CalloutExtensionRecommendation
        ] = None,
        sitelink_extension_recommendation: typing___Optional[
            type___Recommendation.SitelinkExtensionRecommendation
        ] = None,
        call_extension_recommendation: typing___Optional[
            type___Recommendation.CallExtensionRecommendation
        ] = None,
        keyword_match_type_recommendation: typing___Optional[
            type___Recommendation.KeywordMatchTypeRecommendation
        ] = None,
        move_unused_budget_recommendation: typing___Optional[
            type___Recommendation.MoveUnusedBudgetRecommendation
        ] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal[
            "ad_group",
            b"ad_group",
            "call_extension_recommendation",
            b"call_extension_recommendation",
            "callout_extension_recommendation",
            b"callout_extension_recommendation",
            "campaign",
            b"campaign",
            "campaign_budget",
            b"campaign_budget",
            "campaign_budget_recommendation",
            b"campaign_budget_recommendation",
            "dismissed",
            b"dismissed",
            "enhanced_cpc_opt_in_recommendation",
            b"enhanced_cpc_opt_in_recommendation",
            "impact",
            b"impact",
            "keyword_match_type_recommendation",
            b"keyword_match_type_recommendation",
            "keyword_recommendation",
            b"keyword_recommendation",
            "maximize_clicks_opt_in_recommendation",
            b"maximize_clicks_opt_in_recommendation",
            "maximize_conversions_opt_in_recommendation",
            b"maximize_conversions_opt_in_recommendation",
            "move_unused_budget_recommendation",
            b"move_unused_budget_recommendation",
            "optimize_ad_rotation_recommendation",
            b"optimize_ad_rotation_recommendation",
            "recommendation",
            b"recommendation",
            "search_partners_opt_in_recommendation",
            b"search_partners_opt_in_recommendation",
            "sitelink_extension_recommendation",
            b"sitelink_extension_recommendation",
            "target_cpa_opt_in_recommendation",
            b"target_cpa_opt_in_recommendation",
            "text_ad_recommendation",
            b"text_ad_recommendation",
        ],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "ad_group",
            b"ad_group",
            "call_extension_recommendation",
            b"call_extension_recommendation",
            "callout_extension_recommendation",
            b"callout_extension_recommendation",
            "campaign",
            b"campaign",
            "campaign_budget",
            b"campaign_budget",
            "campaign_budget_recommendation",
            b"campaign_budget_recommendation",
            "dismissed",
            b"dismissed",
            "enhanced_cpc_opt_in_recommendation",
            b"enhanced_cpc_opt_in_recommendation",
            "impact",
            b"impact",
            "keyword_match_type_recommendation",
            b"keyword_match_type_recommendation",
            "keyword_recommendation",
            b"keyword_recommendation",
            "maximize_clicks_opt_in_recommendation",
            b"maximize_clicks_opt_in_recommendation",
            "maximize_conversions_opt_in_recommendation",
            b"maximize_conversions_opt_in_recommendation",
            "move_unused_budget_recommendation",
            b"move_unused_budget_recommendation",
            "optimize_ad_rotation_recommendation",
            b"optimize_ad_rotation_recommendation",
            "recommendation",
            b"recommendation",
            "resource_name",
            b"resource_name",
            "search_partners_opt_in_recommendation",
            b"search_partners_opt_in_recommendation",
            "sitelink_extension_recommendation",
            b"sitelink_extension_recommendation",
            "target_cpa_opt_in_recommendation",
            b"target_cpa_opt_in_recommendation",
            "text_ad_recommendation",
            b"text_ad_recommendation",
            "type",
            b"type",
        ],
    ) -> None: ...
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal["recommendation", b"recommendation"],
    ) -> typing_extensions___Literal[
        "campaign_budget_recommendation",
        "keyword_recommendation",
        "text_ad_recommendation",
        "target_cpa_opt_in_recommendation",
        "maximize_conversions_opt_in_recommendation",
        "enhanced_cpc_opt_in_recommendation",
        "search_partners_opt_in_recommendation",
        "maximize_clicks_opt_in_recommendation",
        "optimize_ad_rotation_recommendation",
        "callout_extension_recommendation",
        "sitelink_extension_recommendation",
        "call_extension_recommendation",
        "keyword_match_type_recommendation",
        "move_unused_budget_recommendation",
    ]: ...

type___Recommendation = Recommendation



# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import (
    Optional as typing___Optional,
    Text as typing___Text,
    overload as typing___overload,
)

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.message import Message as google___protobuf___message___Message
from typing_extensions import Literal as typing_extensions___Literal

from google.ads.google_ads.v6.proto.enums.access_role_pb2 import (
    AccessRoleEnum as google___ads___googleads___v6___enums___access_role_pb2___AccessRoleEnum,
)

builtin___bool = bool
builtin___bytes = bytes
builtin___float = float
builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class CustomerUserAccess(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    resource_name: typing___Text = ...
    user_id: builtin___int = ...
    email_address: typing___Text = ...
    access_role: google___ads___googleads___v6___enums___access_role_pb2___AccessRoleEnum.AccessRoleValue = ...
    access_creation_date_time: typing___Text = ...
    inviter_user_email_address: typing___Text = ...
    def __init__(
        self,
        *,
        resource_name: typing___Optional[typing___Text] = None,
        user_id: typing___Optional[builtin___int] = None,
        email_address: typing___Optional[typing___Text] = None,
        access_role: typing___Optional[
            google___ads___googleads___v6___enums___access_role_pb2___AccessRoleEnum.AccessRoleValue
        ] = None,
        access_creation_date_time: typing___Optional[typing___Text] = None,
        inviter_user_email_address: typing___Optional[typing___Text] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal[
            "_access_creation_date_time",
            b"_access_creation_date_time",
            "_email_address",
            b"_email_address",
            "_inviter_user_email_address",
            b"_inviter_user_email_address",
            "access_creation_date_time",
            b"access_creation_date_time",
            "email_address",
            b"email_address",
            "inviter_user_email_address",
            b"inviter_user_email_address",
        ],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "_access_creation_date_time",
            b"_access_creation_date_time",
            "_email_address",
            b"_email_address",
            "_inviter_user_email_address",
            b"_inviter_user_email_address",
            "access_creation_date_time",
            b"access_creation_date_time",
            "access_role",
            b"access_role",
            "email_address",
            b"email_address",
            "inviter_user_email_address",
            b"inviter_user_email_address",
            "resource_name",
            b"resource_name",
            "user_id",
            b"user_id",
        ],
    ) -> None: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_access_creation_date_time", b"_access_creation_date_time"
        ],
    ) -> typing_extensions___Literal["access_creation_date_time"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal["_email_address", b"_email_address"],
    ) -> typing_extensions___Literal["email_address"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_inviter_user_email_address", b"_inviter_user_email_address"
        ],
    ) -> typing_extensions___Literal["inviter_user_email_address"]: ...

type___CustomerUserAccess = CustomerUserAccess



# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import NewType as typing___NewType, cast as typing___cast

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.enum_type_wrapper import (
    _EnumTypeWrapper as google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper,
)
from google.protobuf.message import Message as google___protobuf___message___Message

builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class SharedSetErrorEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    SharedSetErrorValue = typing___NewType("SharedSetErrorValue", builtin___int)
    type___SharedSetErrorValue = SharedSetErrorValue
    SharedSetError: _SharedSetError
    class _SharedSetError(
        google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[
            SharedSetErrorEnum.SharedSetErrorValue
        ]
    ):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        UNSPECIFIED = typing___cast(SharedSetErrorEnum.SharedSetErrorValue, 0)
        UNKNOWN = typing___cast(SharedSetErrorEnum.SharedSetErrorValue, 1)
        CUSTOMER_CANNOT_CREATE_SHARED_SET_OF_THIS_TYPE = typing___cast(
            SharedSetErrorEnum.SharedSetErrorValue, 2
        )
        DUPLICATE_NAME = typing___cast(SharedSetErrorEnum.SharedSetErrorValue, 3)
        SHARED_SET_REMOVED = typing___cast(SharedSetErrorEnum.SharedSetErrorValue, 4)
        SHARED_SET_IN_USE = typing___cast(SharedSetErrorEnum.SharedSetErrorValue, 5)
    UNSPECIFIED = typing___cast(SharedSetErrorEnum.SharedSetErrorValue, 0)
    UNKNOWN = typing___cast(SharedSetErrorEnum.SharedSetErrorValue, 1)
    CUSTOMER_CANNOT_CREATE_SHARED_SET_OF_THIS_TYPE = typing___cast(
        SharedSetErrorEnum.SharedSetErrorValue, 2
    )
    DUPLICATE_NAME = typing___cast(SharedSetErrorEnum.SharedSetErrorValue, 3)
    SHARED_SET_REMOVED = typing___cast(SharedSetErrorEnum.SharedSetErrorValue, 4)
    SHARED_SET_IN_USE = typing___cast(SharedSetErrorEnum.SharedSetErrorValue, 5)
    type___SharedSetError = SharedSetError
    def __init__(self,) -> None: ...

type___SharedSetErrorEnum = SharedSetErrorEnum



from typing import Any

class AdGroupAdLabelServiceStub:
    GetAdGroupAdLabel: Any = ...
    MutateAdGroupAdLabels: Any = ...
    def __init__(self, channel: Any) -> None: ...

class AdGroupAdLabelServiceServicer:
    def GetAdGroupAdLabel(self, request: Any, context: Any) -> None: ...
    def MutateAdGroupAdLabels(self, request: Any, context: Any) -> None: ...

def add_AdGroupAdLabelServiceServicer_to_server(servicer: Any, server: Any) -> None: ...



# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import NewType as typing___NewType, cast as typing___cast

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.enum_type_wrapper import (
    _EnumTypeWrapper as google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper,
)
from google.protobuf.message import Message as google___protobuf___message___Message

builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class SharedCriterionErrorEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    SharedCriterionErrorValue = typing___NewType(
        "SharedCriterionErrorValue", builtin___int
    )
    type___SharedCriterionErrorValue = SharedCriterionErrorValue
    SharedCriterionError: _SharedCriterionError
    class _SharedCriterionError(
        google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[
            SharedCriterionErrorEnum.SharedCriterionErrorValue
        ]
    ):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        UNSPECIFIED = typing___cast(
            SharedCriterionErrorEnum.SharedCriterionErrorValue, 0
        )
        UNKNOWN = typing___cast(SharedCriterionErrorEnum.SharedCriterionErrorValue, 1)
        CRITERION_TYPE_NOT_ALLOWED_FOR_SHARED_SET_TYPE = typing___cast(
            SharedCriterionErrorEnum.SharedCriterionErrorValue, 2
        )
    UNSPECIFIED = typing___cast(SharedCriterionErrorEnum.SharedCriterionErrorValue, 0)
    UNKNOWN = typing___cast(SharedCriterionErrorEnum.SharedCriterionErrorValue, 1)
    CRITERION_TYPE_NOT_ALLOWED_FOR_SHARED_SET_TYPE = typing___cast(
        SharedCriterionErrorEnum.SharedCriterionErrorValue, 2
    )
    type___SharedCriterionError = SharedCriterionError
    def __init__(self,) -> None: ...

type___SharedCriterionErrorEnum = SharedCriterionErrorEnum



# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import NewType as typing___NewType, cast as typing___cast

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.enum_type_wrapper import (
    _EnumTypeWrapper as google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper,
)
from google.protobuf.message import Message as google___protobuf___message___Message

builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class PriceExtensionTypeEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    PriceExtensionTypeValue = typing___NewType("PriceExtensionTypeValue", builtin___int)
    type___PriceExtensionTypeValue = PriceExtensionTypeValue
    PriceExtensionType: _PriceExtensionType
    class _PriceExtensionType(
        google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[
            PriceExtensionTypeEnum.PriceExtensionTypeValue
        ]
    ):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        UNSPECIFIED = typing___cast(PriceExtensionTypeEnum.PriceExtensionTypeValue, 0)
        UNKNOWN = typing___cast(PriceExtensionTypeEnum.PriceExtensionTypeValue, 1)
        BRANDS = typing___cast(PriceExtensionTypeEnum.PriceExtensionTypeValue, 2)
        EVENTS = typing___cast(PriceExtensionTypeEnum.PriceExtensionTypeValue, 3)
        LOCATIONS = typing___cast(PriceExtensionTypeEnum.PriceExtensionTypeValue, 4)
        NEIGHBORHOODS = typing___cast(PriceExtensionTypeEnum.PriceExtensionTypeValue, 5)
        PRODUCT_CATEGORIES = typing___cast(
            PriceExtensionTypeEnum.PriceExtensionTypeValue, 6
        )
        PRODUCT_TIERS = typing___cast(PriceExtensionTypeEnum.PriceExtensionTypeValue, 7)
        SERVICES = typing___cast(PriceExtensionTypeEnum.PriceExtensionTypeValue, 8)
        SERVICE_CATEGORIES = typing___cast(
            PriceExtensionTypeEnum.PriceExtensionTypeValue, 9
        )
        SERVICE_TIERS = typing___cast(
            PriceExtensionTypeEnum.PriceExtensionTypeValue, 10
        )
    UNSPECIFIED = typing___cast(PriceExtensionTypeEnum.PriceExtensionTypeValue, 0)
    UNKNOWN = typing___cast(PriceExtensionTypeEnum.PriceExtensionTypeValue, 1)
    BRANDS = typing___cast(PriceExtensionTypeEnum.PriceExtensionTypeValue, 2)
    EVENTS = typing___cast(PriceExtensionTypeEnum.PriceExtensionTypeValue, 3)
    LOCATIONS = typing___cast(PriceExtensionTypeEnum.PriceExtensionTypeValue, 4)
    NEIGHBORHOODS = typing___cast(PriceExtensionTypeEnum.PriceExtensionTypeValue, 5)
    PRODUCT_CATEGORIES = typing___cast(
        PriceExtensionTypeEnum.PriceExtensionTypeValue, 6
    )
    PRODUCT_TIERS = typing___cast(PriceExtensionTypeEnum.PriceExtensionTypeValue, 7)
    SERVICES = typing___cast(PriceExtensionTypeEnum.PriceExtensionTypeValue, 8)
    SERVICE_CATEGORIES = typing___cast(
        PriceExtensionTypeEnum.PriceExtensionTypeValue, 9
    )
    SERVICE_TIERS = typing___cast(PriceExtensionTypeEnum.PriceExtensionTypeValue, 10)
    type___PriceExtensionType = PriceExtensionType
    def __init__(self,) -> None: ...

type___PriceExtensionTypeEnum = PriceExtensionTypeEnum



from typing import Any

class GeographicViewServiceStub:
    GetGeographicView: Any = ...
    def __init__(self, channel: Any) -> None: ...

class GeographicViewServiceServicer:
    def GetGeographicView(self, request: Any, context: Any) -> None: ...

def add_GeographicViewServiceServicer_to_server(servicer: Any, server: Any) -> None: ...



# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import NewType as typing___NewType, cast as typing___cast

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.enum_type_wrapper import (
    _EnumTypeWrapper as google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper,
)
from google.protobuf.message import Message as google___protobuf___message___Message

builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class CustomerUserAccessErrorEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    CustomerUserAccessErrorValue = typing___NewType(
        "CustomerUserAccessErrorValue", builtin___int
    )
    type___CustomerUserAccessErrorValue = CustomerUserAccessErrorValue
    CustomerUserAccessError: _CustomerUserAccessError
    class _CustomerUserAccessError(
        google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[
            CustomerUserAccessErrorEnum.CustomerUserAccessErrorValue
        ]
    ):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        UNSPECIFIED = typing___cast(
            CustomerUserAccessErrorEnum.CustomerUserAccessErrorValue, 0
        )
        UNKNOWN = typing___cast(
            CustomerUserAccessErrorEnum.CustomerUserAccessErrorValue, 1
        )
        INVALID_USER_ID = typing___cast(
            CustomerUserAccessErrorEnum.CustomerUserAccessErrorValue, 2
        )
        REMOVAL_DISALLOWED = typing___cast(
            CustomerUserAccessErrorEnum.CustomerUserAccessErrorValue, 3
        )
        DISALLOWED_ACCESS_ROLE = typing___cast(
            CustomerUserAccessErrorEnum.CustomerUserAccessErrorValue, 4
        )
        LAST_ADMIN_USER_OF_SERVING_CUSTOMER = typing___cast(
            CustomerUserAccessErrorEnum.CustomerUserAccessErrorValue, 5
        )
        LAST_ADMIN_USER_OF_MANAGER = typing___cast(
            CustomerUserAccessErrorEnum.CustomerUserAccessErrorValue, 6
        )
    UNSPECIFIED = typing___cast(
        CustomerUserAccessErrorEnum.CustomerUserAccessErrorValue, 0
    )
    UNKNOWN = typing___cast(CustomerUserAccessErrorEnum.CustomerUserAccessErrorValue, 1)
    INVALID_USER_ID = typing___cast(
        CustomerUserAccessErrorEnum.CustomerUserAccessErrorValue, 2
    )
    REMOVAL_DISALLOWED = typing___cast(
        CustomerUserAccessErrorEnum.CustomerUserAccessErrorValue, 3
    )
    DISALLOWED_ACCESS_ROLE = typing___cast(
        CustomerUserAccessErrorEnum.CustomerUserAccessErrorValue, 4
    )
    LAST_ADMIN_USER_OF_SERVING_CUSTOMER = typing___cast(
        CustomerUserAccessErrorEnum.CustomerUserAccessErrorValue, 5
    )
    LAST_ADMIN_USER_OF_MANAGER = typing___cast(
        CustomerUserAccessErrorEnum.CustomerUserAccessErrorValue, 6
    )
    type___CustomerUserAccessError = CustomerUserAccessError
    def __init__(self,) -> None: ...

type___CustomerUserAccessErrorEnum = CustomerUserAccessErrorEnum



# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import (
    Optional as typing___Optional,
    Text as typing___Text,
    overload as typing___overload,
)

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.message import Message as google___protobuf___message___Message
from typing_extensions import Literal as typing_extensions___Literal

builtin___bool = bool
builtin___bytes = bytes
builtin___float = float
builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class PaymentsAccount(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    resource_name: typing___Text = ...
    payments_account_id: typing___Text = ...
    name: typing___Text = ...
    currency_code: typing___Text = ...
    payments_profile_id: typing___Text = ...
    secondary_payments_profile_id: typing___Text = ...
    paying_manager_customer: typing___Text = ...
    def __init__(
        self,
        *,
        resource_name: typing___Optional[typing___Text] = None,
        payments_account_id: typing___Optional[typing___Text] = None,
        name: typing___Optional[typing___Text] = None,
        currency_code: typing___Optional[typing___Text] = None,
        payments_profile_id: typing___Optional[typing___Text] = None,
        secondary_payments_profile_id: typing___Optional[typing___Text] = None,
        paying_manager_customer: typing___Optional[typing___Text] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal[
            "_currency_code",
            b"_currency_code",
            "_name",
            b"_name",
            "_paying_manager_customer",
            b"_paying_manager_customer",
            "_payments_account_id",
            b"_payments_account_id",
            "_payments_profile_id",
            b"_payments_profile_id",
            "_secondary_payments_profile_id",
            b"_secondary_payments_profile_id",
            "currency_code",
            b"currency_code",
            "name",
            b"name",
            "paying_manager_customer",
            b"paying_manager_customer",
            "payments_account_id",
            b"payments_account_id",
            "payments_profile_id",
            b"payments_profile_id",
            "secondary_payments_profile_id",
            b"secondary_payments_profile_id",
        ],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "_currency_code",
            b"_currency_code",
            "_name",
            b"_name",
            "_paying_manager_customer",
            b"_paying_manager_customer",
            "_payments_account_id",
            b"_payments_account_id",
            "_payments_profile_id",
            b"_payments_profile_id",
            "_secondary_payments_profile_id",
            b"_secondary_payments_profile_id",
            "currency_code",
            b"currency_code",
            "name",
            b"name",
            "paying_manager_customer",
            b"paying_manager_customer",
            "payments_account_id",
            b"payments_account_id",
            "payments_profile_id",
            b"payments_profile_id",
            "resource_name",
            b"resource_name",
            "secondary_payments_profile_id",
            b"secondary_payments_profile_id",
        ],
    ) -> None: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal["_currency_code", b"_currency_code"],
    ) -> typing_extensions___Literal["currency_code"]: ...
    @typing___overload
    def WhichOneof(
        self, oneof_group: typing_extensions___Literal["_name", b"_name"]
    ) -> typing_extensions___Literal["name"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_paying_manager_customer", b"_paying_manager_customer"
        ],
    ) -> typing_extensions___Literal["paying_manager_customer"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_payments_account_id", b"_payments_account_id"
        ],
    ) -> typing_extensions___Literal["payments_account_id"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_payments_profile_id", b"_payments_profile_id"
        ],
    ) -> typing_extensions___Literal["payments_profile_id"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_secondary_payments_profile_id", b"_secondary_payments_profile_id"
        ],
    ) -> typing_extensions___Literal["secondary_payments_profile_id"]: ...

type___PaymentsAccount = PaymentsAccount



# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import Optional as typing___Optional, Text as typing___Text

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.message import Message as google___protobuf___message___Message
from google.protobuf.wrappers_pb2 import (
    Int64Value as google___protobuf___wrappers_pb2___Int64Value,
    StringValue as google___protobuf___wrappers_pb2___StringValue,
)
from typing_extensions import Literal as typing_extensions___Literal

from google.ads.google_ads.v3.proto.enums.geo_target_constant_status_pb2 import (
    GeoTargetConstantStatusEnum as google___ads___googleads___v3___enums___geo_target_constant_status_pb2___GeoTargetConstantStatusEnum,
)

builtin___bool = bool
builtin___bytes = bytes
builtin___float = float
builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class GeoTargetConstant(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    resource_name: typing___Text = ...
    status: google___ads___googleads___v3___enums___geo_target_constant_status_pb2___GeoTargetConstantStatusEnum.GeoTargetConstantStatusValue = ...
    @property
    def id(self) -> google___protobuf___wrappers_pb2___Int64Value: ...
    @property
    def name(self) -> google___protobuf___wrappers_pb2___StringValue: ...
    @property
    def country_code(self) -> google___protobuf___wrappers_pb2___StringValue: ...
    @property
    def target_type(self) -> google___protobuf___wrappers_pb2___StringValue: ...
    @property
    def canonical_name(self) -> google___protobuf___wrappers_pb2___StringValue: ...
    def __init__(
        self,
        *,
        resource_name: typing___Optional[typing___Text] = None,
        id: typing___Optional[google___protobuf___wrappers_pb2___Int64Value] = None,
        name: typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        country_code: typing___Optional[
            google___protobuf___wrappers_pb2___StringValue
        ] = None,
        target_type: typing___Optional[
            google___protobuf___wrappers_pb2___StringValue
        ] = None,
        status: typing___Optional[
            google___ads___googleads___v3___enums___geo_target_constant_status_pb2___GeoTargetConstantStatusEnum.GeoTargetConstantStatusValue
        ] = None,
        canonical_name: typing___Optional[
            google___protobuf___wrappers_pb2___StringValue
        ] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal[
            "canonical_name",
            b"canonical_name",
            "country_code",
            b"country_code",
            "id",
            b"id",
            "name",
            b"name",
            "target_type",
            b"target_type",
        ],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "canonical_name",
            b"canonical_name",
            "country_code",
            b"country_code",
            "id",
            b"id",
            "name",
            b"name",
            "resource_name",
            b"resource_name",
            "status",
            b"status",
            "target_type",
            b"target_type",
        ],
    ) -> None: ...

type___GeoTargetConstant = GeoTargetConstant



from typing import Any

class CampaignBudgetServiceStub:
    GetCampaignBudget: Any = ...
    MutateCampaignBudgets: Any = ...
    def __init__(self, channel: Any) -> None: ...

class CampaignBudgetServiceServicer:
    def GetCampaignBudget(self, request: Any, context: Any) -> None: ...
    def MutateCampaignBudgets(self, request: Any, context: Any) -> None: ...

def add_CampaignBudgetServiceServicer_to_server(servicer: Any, server: Any) -> None: ...



# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import NewType as typing___NewType, cast as typing___cast

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.enum_type_wrapper import (
    _EnumTypeWrapper as google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper,
)
from google.protobuf.message import Message as google___protobuf___message___Message

builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class AffiliateLocationFeedRelationshipTypeEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    AffiliateLocationFeedRelationshipTypeValue = typing___NewType(
        "AffiliateLocationFeedRelationshipTypeValue", builtin___int
    )
    type___AffiliateLocationFeedRelationshipTypeValue = (
        AffiliateLocationFeedRelationshipTypeValue
    )
    AffiliateLocationFeedRelationshipType: _AffiliateLocationFeedRelationshipType
    class _AffiliateLocationFeedRelationshipType(
        google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[
            AffiliateLocationFeedRelationshipTypeEnum.AffiliateLocationFeedRelationshipTypeValue
        ]
    ):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        UNSPECIFIED = typing___cast(
            AffiliateLocationFeedRelationshipTypeEnum.AffiliateLocationFeedRelationshipTypeValue,
            0,
        )
        UNKNOWN = typing___cast(
            AffiliateLocationFeedRelationshipTypeEnum.AffiliateLocationFeedRelationshipTypeValue,
            1,
        )
        GENERAL_RETAILER = typing___cast(
            AffiliateLocationFeedRelationshipTypeEnum.AffiliateLocationFeedRelationshipTypeValue,
            2,
        )
    UNSPECIFIED = typing___cast(
        AffiliateLocationFeedRelationshipTypeEnum.AffiliateLocationFeedRelationshipTypeValue,
        0,
    )
    UNKNOWN = typing___cast(
        AffiliateLocationFeedRelationshipTypeEnum.AffiliateLocationFeedRelationshipTypeValue,
        1,
    )
    GENERAL_RETAILER = typing___cast(
        AffiliateLocationFeedRelationshipTypeEnum.AffiliateLocationFeedRelationshipTypeValue,
        2,
    )
    type___AffiliateLocationFeedRelationshipType = AffiliateLocationFeedRelationshipType
    def __init__(self,) -> None: ...

type___AffiliateLocationFeedRelationshipTypeEnum = (
    AffiliateLocationFeedRelationshipTypeEnum
)



# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import NewType as typing___NewType, cast as typing___cast

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.enum_type_wrapper import (
    _EnumTypeWrapper as google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper,
)
from google.protobuf.message import Message as google___protobuf___message___Message

builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class GeoTargetConstantSuggestionErrorEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    GeoTargetConstantSuggestionErrorValue = typing___NewType(
        "GeoTargetConstantSuggestionErrorValue", builtin___int
    )
    type___GeoTargetConstantSuggestionErrorValue = GeoTargetConstantSuggestionErrorValue
    GeoTargetConstantSuggestionError: _GeoTargetConstantSuggestionError
    class _GeoTargetConstantSuggestionError(
        google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[
            GeoTargetConstantSuggestionErrorEnum.GeoTargetConstantSuggestionErrorValue
        ]
    ):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        UNSPECIFIED = typing___cast(
            GeoTargetConstantSuggestionErrorEnum.GeoTargetConstantSuggestionErrorValue,
            0,
        )
        UNKNOWN = typing___cast(
            GeoTargetConstantSuggestionErrorEnum.GeoTargetConstantSuggestionErrorValue,
            1,
        )
        LOCATION_NAME_SIZE_LIMIT = typing___cast(
            GeoTargetConstantSuggestionErrorEnum.GeoTargetConstantSuggestionErrorValue,
            2,
        )
        LOCATION_NAME_LIMIT = typing___cast(
            GeoTargetConstantSuggestionErrorEnum.GeoTargetConstantSuggestionErrorValue,
            3,
        )
        INVALID_COUNTRY_CODE = typing___cast(
            GeoTargetConstantSuggestionErrorEnum.GeoTargetConstantSuggestionErrorValue,
            4,
        )
        REQUEST_PARAMETERS_UNSET = typing___cast(
            GeoTargetConstantSuggestionErrorEnum.GeoTargetConstantSuggestionErrorValue,
            5,
        )
    UNSPECIFIED = typing___cast(
        GeoTargetConstantSuggestionErrorEnum.GeoTargetConstantSuggestionErrorValue, 0
    )
    UNKNOWN = typing___cast(
        GeoTargetConstantSuggestionErrorEnum.GeoTargetConstantSuggestionErrorValue, 1
    )
    LOCATION_NAME_SIZE_LIMIT = typing___cast(
        GeoTargetConstantSuggestionErrorEnum.GeoTargetConstantSuggestionErrorValue, 2
    )
    LOCATION_NAME_LIMIT = typing___cast(
        GeoTargetConstantSuggestionErrorEnum.GeoTargetConstantSuggestionErrorValue, 3
    )
    INVALID_COUNTRY_CODE = typing___cast(
        GeoTargetConstantSuggestionErrorEnum.GeoTargetConstantSuggestionErrorValue, 4
    )
    REQUEST_PARAMETERS_UNSET = typing___cast(
        GeoTargetConstantSuggestionErrorEnum.GeoTargetConstantSuggestionErrorValue, 5
    )
    type___GeoTargetConstantSuggestionError = GeoTargetConstantSuggestionError
    def __init__(self,) -> None: ...

type___GeoTargetConstantSuggestionErrorEnum = GeoTargetConstantSuggestionErrorEnum



# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import (
    Iterable as typing___Iterable,
    Optional as typing___Optional,
    Text as typing___Text,
    overload as typing___overload,
)

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.containers import (
    RepeatedCompositeFieldContainer as google___protobuf___internal___containers___RepeatedCompositeFieldContainer,
    RepeatedScalarFieldContainer as google___protobuf___internal___containers___RepeatedScalarFieldContainer,
)
from google.protobuf.message import Message as google___protobuf___message___Message
from typing_extensions import Literal as typing_extensions___Literal

from google.ads.google_ads.v6.proto.common.dates_pb2 import (
    DateRange as google___ads___googleads___v6___common___dates_pb2___DateRange,
)
from google.ads.google_ads.v6.proto.enums.invoice_type_pb2 import (
    InvoiceTypeEnum as google___ads___googleads___v6___enums___invoice_type_pb2___InvoiceTypeEnum,
)

builtin___bool = bool
builtin___bytes = bytes
builtin___float = float
builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class Invoice(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    class AccountBudgetSummary(google___protobuf___message___Message):
        DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
        customer: typing___Text = ...
        customer_descriptive_name: typing___Text = ...
        account_budget: typing___Text = ...
        account_budget_name: typing___Text = ...
        purchase_order_number: typing___Text = ...
        subtotal_amount_micros: builtin___int = ...
        tax_amount_micros: builtin___int = ...
        total_amount_micros: builtin___int = ...
        @property
        def billable_activity_date_range(
            self,
        ) -> google___ads___googleads___v6___common___dates_pb2___DateRange: ...
        def __init__(
            self,
            *,
            customer: typing___Optional[typing___Text] = None,
            customer_descriptive_name: typing___Optional[typing___Text] = None,
            account_budget: typing___Optional[typing___Text] = None,
            account_budget_name: typing___Optional[typing___Text] = None,
            purchase_order_number: typing___Optional[typing___Text] = None,
            subtotal_amount_micros: typing___Optional[builtin___int] = None,
            tax_amount_micros: typing___Optional[builtin___int] = None,
            total_amount_micros: typing___Optional[builtin___int] = None,
            billable_activity_date_range: typing___Optional[
                google___ads___googleads___v6___common___dates_pb2___DateRange
            ] = None,
        ) -> None: ...
        def HasField(
            self,
            field_name: typing_extensions___Literal[
                "_account_budget",
                b"_account_budget",
                "_account_budget_name",
                b"_account_budget_name",
                "_customer",
                b"_customer",
                "_customer_descriptive_name",
                b"_customer_descriptive_name",
                "_purchase_order_number",
                b"_purchase_order_number",
                "_subtotal_amount_micros",
                b"_subtotal_amount_micros",
                "_tax_amount_micros",
                b"_tax_amount_micros",
                "_total_amount_micros",
                b"_total_amount_micros",
                "account_budget",
                b"account_budget",
                "account_budget_name",
                b"account_budget_name",
                "billable_activity_date_range",
                b"billable_activity_date_range",
                "customer",
                b"customer",
                "customer_descriptive_name",
                b"customer_descriptive_name",
                "purchase_order_number",
                b"purchase_order_number",
                "subtotal_amount_micros",
                b"subtotal_amount_micros",
                "tax_amount_micros",
                b"tax_amount_micros",
                "total_amount_micros",
                b"total_amount_micros",
            ],
        ) -> builtin___bool: ...
        def ClearField(
            self,
            field_name: typing_extensions___Literal[
                "_account_budget",
                b"_account_budget",
                "_account_budget_name",
                b"_account_budget_name",
                "_customer",
                b"_customer",
                "_customer_descriptive_name",
                b"_customer_descriptive_name",
                "_purchase_order_number",
                b"_purchase_order_number",
                "_subtotal_amount_micros",
                b"_subtotal_amount_micros",
                "_tax_amount_micros",
                b"_tax_amount_micros",
                "_total_amount_micros",
                b"_total_amount_micros",
                "account_budget",
                b"account_budget",
                "account_budget_name",
                b"account_budget_name",
                "billable_activity_date_range",
                b"billable_activity_date_range",
                "customer",
                b"customer",
                "customer_descriptive_name",
                b"customer_descriptive_name",
                "purchase_order_number",
                b"purchase_order_number",
                "subtotal_amount_micros",
                b"subtotal_amount_micros",
                "tax_amount_micros",
                b"tax_amount_micros",
                "total_amount_micros",
                b"total_amount_micros",
            ],
        ) -> None: ...
        @typing___overload
        def WhichOneof(
            self,
            oneof_group: typing_extensions___Literal[
                "_account_budget", b"_account_budget"
            ],
        ) -> typing_extensions___Literal["account_budget"]: ...
        @typing___overload
        def WhichOneof(
            self,
            oneof_group: typing_extensions___Literal[
                "_account_budget_name", b"_account_budget_name"
            ],
        ) -> typing_extensions___Literal["account_budget_name"]: ...
        @typing___overload
        def WhichOneof(
            self, oneof_group: typing_extensions___Literal["_customer", b"_customer"]
        ) -> typing_extensions___Literal["customer"]: ...
        @typing___overload
        def WhichOneof(
            self,
            oneof_group: typing_extensions___Literal[
                "_customer_descriptive_name", b"_customer_descriptive_name"
            ],
        ) -> typing_extensions___Literal["customer_descriptive_name"]: ...
        @typing___overload
        def WhichOneof(
            self,
            oneof_group: typing_extensions___Literal[
                "_purchase_order_number", b"_purchase_order_number"
            ],
        ) -> typing_extensions___Literal["purchase_order_number"]: ...
        @typing___overload
        def WhichOneof(
            self,
            oneof_group: typing_extensions___Literal[
                "_subtotal_amount_micros", b"_subtotal_amount_micros"
            ],
        ) -> typing_extensions___Literal["subtotal_amount_micros"]: ...
        @typing___overload
        def WhichOneof(
            self,
            oneof_group: typing_extensions___Literal[
                "_tax_amount_micros", b"_tax_amount_micros"
            ],
        ) -> typing_extensions___Literal["tax_amount_micros"]: ...
        @typing___overload
        def WhichOneof(
            self,
            oneof_group: typing_extensions___Literal[
                "_total_amount_micros", b"_total_amount_micros"
            ],
        ) -> typing_extensions___Literal["total_amount_micros"]: ...
    type___AccountBudgetSummary = AccountBudgetSummary

    resource_name: typing___Text = ...
    id: typing___Text = ...
    type: google___ads___googleads___v6___enums___invoice_type_pb2___InvoiceTypeEnum.InvoiceTypeValue = ...
    billing_setup: typing___Text = ...
    payments_account_id: typing___Text = ...
    payments_profile_id: typing___Text = ...
    issue_date: typing___Text = ...
    due_date: typing___Text = ...
    currency_code: typing___Text = ...
    adjustments_subtotal_amount_micros: builtin___int = ...
    adjustments_tax_amount_micros: builtin___int = ...
    adjustments_total_amount_micros: builtin___int = ...
    regulatory_costs_subtotal_amount_micros: builtin___int = ...
    regulatory_costs_tax_amount_micros: builtin___int = ...
    regulatory_costs_total_amount_micros: builtin___int = ...
    subtotal_amount_micros: builtin___int = ...
    tax_amount_micros: builtin___int = ...
    total_amount_micros: builtin___int = ...
    corrected_invoice: typing___Text = ...
    replaced_invoices: google___protobuf___internal___containers___RepeatedScalarFieldContainer[
        typing___Text
    ] = ...
    pdf_url: typing___Text = ...
    @property
    def service_date_range(
        self,
    ) -> google___ads___googleads___v6___common___dates_pb2___DateRange: ...
    @property
    def account_budget_summaries(
        self,
    ) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[
        type___Invoice.AccountBudgetSummary
    ]: ...
    def __init__(
        self,
        *,
        resource_name: typing___Optional[typing___Text] = None,
        id: typing___Optional[typing___Text] = None,
        type: typing___Optional[
            google___ads___googleads___v6___enums___invoice_type_pb2___InvoiceTypeEnum.InvoiceTypeValue
        ] = None,
        billing_setup: typing___Optional[typing___Text] = None,
        payments_account_id: typing___Optional[typing___Text] = None,
        payments_profile_id: typing___Optional[typing___Text] = None,
        issue_date: typing___Optional[typing___Text] = None,
        due_date: typing___Optional[typing___Text] = None,
        service_date_range: typing___Optional[
            google___ads___googleads___v6___common___dates_pb2___DateRange
        ] = None,
        currency_code: typing___Optional[typing___Text] = None,
        adjustments_subtotal_amount_micros: typing___Optional[builtin___int] = None,
        adjustments_tax_amount_micros: typing___Optional[builtin___int] = None,
        adjustments_total_amount_micros: typing___Optional[builtin___int] = None,
        regulatory_costs_subtotal_amount_micros: typing___Optional[
            builtin___int
        ] = None,
        regulatory_costs_tax_amount_micros: typing___Optional[builtin___int] = None,
        regulatory_costs_total_amount_micros: typing___Optional[builtin___int] = None,
        subtotal_amount_micros: typing___Optional[builtin___int] = None,
        tax_amount_micros: typing___Optional[builtin___int] = None,
        total_amount_micros: typing___Optional[builtin___int] = None,
        corrected_invoice: typing___Optional[typing___Text] = None,
        replaced_invoices: typing___Optional[typing___Iterable[typing___Text]] = None,
        pdf_url: typing___Optional[typing___Text] = None,
        account_budget_summaries: typing___Optional[
            typing___Iterable[type___Invoice.AccountBudgetSummary]
        ] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal[
            "_billing_setup",
            b"_billing_setup",
            "_corrected_invoice",
            b"_corrected_invoice",
            "_currency_code",
            b"_currency_code",
            "_due_date",
            b"_due_date",
            "_id",
            b"_id",
            "_issue_date",
            b"_issue_date",
            "_payments_account_id",
            b"_payments_account_id",
            "_payments_profile_id",
            b"_payments_profile_id",
            "_pdf_url",
            b"_pdf_url",
            "_subtotal_amount_micros",
            b"_subtotal_amount_micros",
            "_tax_amount_micros",
            b"_tax_amount_micros",
            "_total_amount_micros",
            b"_total_amount_micros",
            "billing_setup",
            b"billing_setup",
            "corrected_invoice",
            b"corrected_invoice",
            "currency_code",
            b"currency_code",
            "due_date",
            b"due_date",
            "id",
            b"id",
            "issue_date",
            b"issue_date",
            "payments_account_id",
            b"payments_account_id",
            "payments_profile_id",
            b"payments_profile_id",
            "pdf_url",
            b"pdf_url",
            "service_date_range",
            b"service_date_range",
            "subtotal_amount_micros",
            b"subtotal_amount_micros",
            "tax_amount_micros",
            b"tax_amount_micros",
            "total_amount_micros",
            b"total_amount_micros",
        ],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "_billing_setup",
            b"_billing_setup",
            "_corrected_invoice",
            b"_corrected_invoice",
            "_currency_code",
            b"_currency_code",
            "_due_date",
            b"_due_date",
            "_id",
            b"_id",
            "_issue_date",
            b"_issue_date",
            "_payments_account_id",
            b"_payments_account_id",
            "_payments_profile_id",
            b"_payments_profile_id",
            "_pdf_url",
            b"_pdf_url",
            "_subtotal_amount_micros",
            b"_subtotal_amount_micros",
            "_tax_amount_micros",
            b"_tax_amount_micros",
            "_total_amount_micros",
            b"_total_amount_micros",
            "account_budget_summaries",
            b"account_budget_summaries",
            "adjustments_subtotal_amount_micros",
            b"adjustments_subtotal_amount_micros",
            "adjustments_tax_amount_micros",
            b"adjustments_tax_amount_micros",
            "adjustments_total_amount_micros",
            b"adjustments_total_amount_micros",
            "billing_setup",
            b"billing_setup",
            "corrected_invoice",
            b"corrected_invoice",
            "currency_code",
            b"currency_code",
            "due_date",
            b"due_date",
            "id",
            b"id",
            "issue_date",
            b"issue_date",
            "payments_account_id",
            b"payments_account_id",
            "payments_profile_id",
            b"payments_profile_id",
            "pdf_url",
            b"pdf_url",
            "regulatory_costs_subtotal_amount_micros",
            b"regulatory_costs_subtotal_amount_micros",
            "regulatory_costs_tax_amount_micros",
            b"regulatory_costs_tax_amount_micros",
            "regulatory_costs_total_amount_micros",
            b"regulatory_costs_total_amount_micros",
            "replaced_invoices",
            b"replaced_invoices",
            "resource_name",
            b"resource_name",
            "service_date_range",
            b"service_date_range",
            "subtotal_amount_micros",
            b"subtotal_amount_micros",
            "tax_amount_micros",
            b"tax_amount_micros",
            "total_amount_micros",
            b"total_amount_micros",
            "type",
            b"type",
        ],
    ) -> None: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal["_billing_setup", b"_billing_setup"],
    ) -> typing_extensions___Literal["billing_setup"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_corrected_invoice", b"_corrected_invoice"
        ],
    ) -> typing_extensions___Literal["corrected_invoice"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal["_currency_code", b"_currency_code"],
    ) -> typing_extensions___Literal["currency_code"]: ...
    @typing___overload
    def WhichOneof(
        self, oneof_group: typing_extensions___Literal["_due_date", b"_due_date"]
    ) -> typing_extensions___Literal["due_date"]: ...
    @typing___overload
    def WhichOneof(
        self, oneof_group: typing_extensions___Literal["_id", b"_id"]
    ) -> typing_extensions___Literal["id"]: ...
    @typing___overload
    def WhichOneof(
        self, oneof_group: typing_extensions___Literal["_issue_date", b"_issue_date"]
    ) -> typing_extensions___Literal["issue_date"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_payments_account_id", b"_payments_account_id"
        ],
    ) -> typing_extensions___Literal["payments_account_id"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_payments_profile_id", b"_payments_profile_id"
        ],
    ) -> typing_extensions___Literal["payments_profile_id"]: ...
    @typing___overload
    def WhichOneof(
        self, oneof_group: typing_extensions___Literal["_pdf_url", b"_pdf_url"]
    ) -> typing_extensions___Literal["pdf_url"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_subtotal_amount_micros", b"_subtotal_amount_micros"
        ],
    ) -> typing_extensions___Literal["subtotal_amount_micros"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_tax_amount_micros", b"_tax_amount_micros"
        ],
    ) -> typing_extensions___Literal["tax_amount_micros"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_total_amount_micros", b"_total_amount_micros"
        ],
    ) -> typing_extensions___Literal["total_amount_micros"]: ...

type___Invoice = Invoice



# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import NewType as typing___NewType, cast as typing___cast

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.enum_type_wrapper import (
    _EnumTypeWrapper as google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper,
)
from google.protobuf.message import Message as google___protobuf___message___Message

builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class MediaUploadErrorEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    MediaUploadErrorValue = typing___NewType("MediaUploadErrorValue", builtin___int)
    type___MediaUploadErrorValue = MediaUploadErrorValue
    MediaUploadError: _MediaUploadError
    class _MediaUploadError(
        google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[
            MediaUploadErrorEnum.MediaUploadErrorValue
        ]
    ):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        UNSPECIFIED = typing___cast(MediaUploadErrorEnum.MediaUploadErrorValue, 0)
        UNKNOWN = typing___cast(MediaUploadErrorEnum.MediaUploadErrorValue, 1)
        FILE_TOO_BIG = typing___cast(MediaUploadErrorEnum.MediaUploadErrorValue, 2)
        UNPARSEABLE_IMAGE = typing___cast(MediaUploadErrorEnum.MediaUploadErrorValue, 3)
        ANIMATED_IMAGE_NOT_ALLOWED = typing___cast(
            MediaUploadErrorEnum.MediaUploadErrorValue, 4
        )
        FORMAT_NOT_ALLOWED = typing___cast(
            MediaUploadErrorEnum.MediaUploadErrorValue, 5
        )
        EXTERNAL_URL_NOT_ALLOWED = typing___cast(
            MediaUploadErrorEnum.MediaUploadErrorValue, 6
        )
        INVALID_URL_REFERENCE = typing___cast(
            MediaUploadErrorEnum.MediaUploadErrorValue, 7
        )
        MISSING_PRIMARY_MEDIA_BUNDLE_ENTRY = typing___cast(
            MediaUploadErrorEnum.MediaUploadErrorValue, 8
        )
        ANIMATED_VISUAL_EFFECT = typing___cast(
            MediaUploadErrorEnum.MediaUploadErrorValue, 9
        )
        ANIMATION_TOO_LONG = typing___cast(
            MediaUploadErrorEnum.MediaUploadErrorValue, 10
        )
        ASPECT_RATIO_NOT_ALLOWED = typing___cast(
            MediaUploadErrorEnum.MediaUploadErrorValue, 11
        )
        AUDIO_NOT_ALLOWED_IN_MEDIA_BUNDLE = typing___cast(
            MediaUploadErrorEnum.MediaUploadErrorValue, 12
        )
        CMYK_JPEG_NOT_ALLOWED = typing___cast(
            MediaUploadErrorEnum.MediaUploadErrorValue, 13
        )
        FLASH_NOT_ALLOWED = typing___cast(
            MediaUploadErrorEnum.MediaUploadErrorValue, 14
        )
        FRAME_RATE_TOO_HIGH = typing___cast(
            MediaUploadErrorEnum.MediaUploadErrorValue, 15
        )
        GOOGLE_WEB_DESIGNER_ZIP_FILE_NOT_PUBLISHED = typing___cast(
            MediaUploadErrorEnum.MediaUploadErrorValue, 16
        )
        IMAGE_CONSTRAINTS_VIOLATED = typing___cast(
            MediaUploadErrorEnum.MediaUploadErrorValue, 17
        )
        INVALID_MEDIA_BUNDLE = typing___cast(
            MediaUploadErrorEnum.MediaUploadErrorValue, 18
        )
        INVALID_MEDIA_BUNDLE_ENTRY = typing___cast(
            MediaUploadErrorEnum.MediaUploadErrorValue, 19
        )
        INVALID_MIME_TYPE = typing___cast(
            MediaUploadErrorEnum.MediaUploadErrorValue, 20
        )
        INVALID_PATH = typing___cast(MediaUploadErrorEnum.MediaUploadErrorValue, 21)
        LAYOUT_PROBLEM = typing___cast(MediaUploadErrorEnum.MediaUploadErrorValue, 22)
        MALFORMED_URL = typing___cast(MediaUploadErrorEnum.MediaUploadErrorValue, 23)
        MEDIA_BUNDLE_NOT_ALLOWED = typing___cast(
            MediaUploadErrorEnum.MediaUploadErrorValue, 24
        )
        MEDIA_BUNDLE_NOT_COMPATIBLE_TO_PRODUCT_TYPE = typing___cast(
            MediaUploadErrorEnum.MediaUploadErrorValue, 25
        )
        MEDIA_BUNDLE_REJECTED_BY_MULTIPLE_ASSET_SPECS = typing___cast(
            MediaUploadErrorEnum.MediaUploadErrorValue, 26
        )
        TOO_MANY_FILES_IN_MEDIA_BUNDLE = typing___cast(
            MediaUploadErrorEnum.MediaUploadErrorValue, 27
        )
        UNSUPPORTED_GOOGLE_WEB_DESIGNER_ENVIRONMENT = typing___cast(
            MediaUploadErrorEnum.MediaUploadErrorValue, 28
        )
        UNSUPPORTED_HTML5_FEATURE = typing___cast(
            MediaUploadErrorEnum.MediaUploadErrorValue, 29
        )
        URL_IN_MEDIA_BUNDLE_NOT_SSL_COMPLIANT = typing___cast(
            MediaUploadErrorEnum.MediaUploadErrorValue, 30
        )
        VIDEO_FILE_NAME_TOO_LONG = typing___cast(
            MediaUploadErrorEnum.MediaUploadErrorValue, 31
        )
        VIDEO_MULTIPLE_FILES_WITH_SAME_NAME = typing___cast(
            MediaUploadErrorEnum.MediaUploadErrorValue, 32
        )
        VIDEO_NOT_ALLOWED_IN_MEDIA_BUNDLE = typing___cast(
            MediaUploadErrorEnum.MediaUploadErrorValue, 33
        )
        CANNOT_UPLOAD_MEDIA_TYPE_THROUGH_API = typing___cast(
            MediaUploadErrorEnum.MediaUploadErrorValue, 34
        )
    UNSPECIFIED = typing___cast(MediaUploadErrorEnum.MediaUploadErrorValue, 0)
    UNKNOWN = typing___cast(MediaUploadErrorEnum.MediaUploadErrorValue, 1)
    FILE_TOO_BIG = typing___cast(MediaUploadErrorEnum.MediaUploadErrorValue, 2)
    UNPARSEABLE_IMAGE = typing___cast(MediaUploadErrorEnum.MediaUploadErrorValue, 3)
    ANIMATED_IMAGE_NOT_ALLOWED = typing___cast(
        MediaUploadErrorEnum.MediaUploadErrorValue, 4
    )
    FORMAT_NOT_ALLOWED = typing___cast(MediaUploadErrorEnum.MediaUploadErrorValue, 5)
    EXTERNAL_URL_NOT_ALLOWED = typing___cast(
        MediaUploadErrorEnum.MediaUploadErrorValue, 6
    )
    INVALID_URL_REFERENCE = typing___cast(MediaUploadErrorEnum.MediaUploadErrorValue, 7)
    MISSING_PRIMARY_MEDIA_BUNDLE_ENTRY = typing___cast(
        MediaUploadErrorEnum.MediaUploadErrorValue, 8
    )
    ANIMATED_VISUAL_EFFECT = typing___cast(
        MediaUploadErrorEnum.MediaUploadErrorValue, 9
    )
    ANIMATION_TOO_LONG = typing___cast(MediaUploadErrorEnum.MediaUploadErrorValue, 10)
    ASPECT_RATIO_NOT_ALLOWED = typing___cast(
        MediaUploadErrorEnum.MediaUploadErrorValue, 11
    )
    AUDIO_NOT_ALLOWED_IN_MEDIA_BUNDLE = typing___cast(
        MediaUploadErrorEnum.MediaUploadErrorValue, 12
    )
    CMYK_JPEG_NOT_ALLOWED = typing___cast(
        MediaUploadErrorEnum.MediaUploadErrorValue, 13
    )
    FLASH_NOT_ALLOWED = typing___cast(MediaUploadErrorEnum.MediaUploadErrorValue, 14)
    FRAME_RATE_TOO_HIGH = typing___cast(MediaUploadErrorEnum.MediaUploadErrorValue, 15)
    GOOGLE_WEB_DESIGNER_ZIP_FILE_NOT_PUBLISHED = typing___cast(
        MediaUploadErrorEnum.MediaUploadErrorValue, 16
    )
    IMAGE_CONSTRAINTS_VIOLATED = typing___cast(
        MediaUploadErrorEnum.MediaUploadErrorValue, 17
    )
    INVALID_MEDIA_BUNDLE = typing___cast(MediaUploadErrorEnum.MediaUploadErrorValue, 18)
    INVALID_MEDIA_BUNDLE_ENTRY = typing___cast(
        MediaUploadErrorEnum.MediaUploadErrorValue, 19
    )
    INVALID_MIME_TYPE = typing___cast(MediaUploadErrorEnum.MediaUploadErrorValue, 20)
    INVALID_PATH = typing___cast(MediaUploadErrorEnum.MediaUploadErrorValue, 21)
    LAYOUT_PROBLEM = typing___cast(MediaUploadErrorEnum.MediaUploadErrorValue, 22)
    MALFORMED_URL = typing___cast(MediaUploadErrorEnum.MediaUploadErrorValue, 23)
    MEDIA_BUNDLE_NOT_ALLOWED = typing___cast(
        MediaUploadErrorEnum.MediaUploadErrorValue, 24
    )
    MEDIA_BUNDLE_NOT_COMPATIBLE_TO_PRODUCT_TYPE = typing___cast(
        MediaUploadErrorEnum.MediaUploadErrorValue, 25
    )
    MEDIA_BUNDLE_REJECTED_BY_MULTIPLE_ASSET_SPECS = typing___cast(
        MediaUploadErrorEnum.MediaUploadErrorValue, 26
    )
    TOO_MANY_FILES_IN_MEDIA_BUNDLE = typing___cast(
        MediaUploadErrorEnum.MediaUploadErrorValue, 27
    )
    UNSUPPORTED_GOOGLE_WEB_DESIGNER_ENVIRONMENT = typing___cast(
        MediaUploadErrorEnum.MediaUploadErrorValue, 28
    )
    UNSUPPORTED_HTML5_FEATURE = typing___cast(
        MediaUploadErrorEnum.MediaUploadErrorValue, 29
    )
    URL_IN_MEDIA_BUNDLE_NOT_SSL_COMPLIANT = typing___cast(
        MediaUploadErrorEnum.MediaUploadErrorValue, 30
    )
    VIDEO_FILE_NAME_TOO_LONG = typing___cast(
        MediaUploadErrorEnum.MediaUploadErrorValue, 31
    )
    VIDEO_MULTIPLE_FILES_WITH_SAME_NAME = typing___cast(
        MediaUploadErrorEnum.MediaUploadErrorValue, 32
    )
    VIDEO_NOT_ALLOWED_IN_MEDIA_BUNDLE = typing___cast(
        MediaUploadErrorEnum.MediaUploadErrorValue, 33
    )
    CANNOT_UPLOAD_MEDIA_TYPE_THROUGH_API = typing___cast(
        MediaUploadErrorEnum.MediaUploadErrorValue, 34
    )
    type___MediaUploadError = MediaUploadError
    def __init__(self,) -> None: ...

type___MediaUploadErrorEnum = MediaUploadErrorEnum



# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import (
    Optional as typing___Optional,
    Text as typing___Text,
    overload as typing___overload,
)

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.message import Message as google___protobuf___message___Message
from typing_extensions import Literal as typing_extensions___Literal

from google.ads.google_ads.v6.proto.common.bidding_pb2 import (
    EnhancedCpc as google___ads___googleads___v6___common___bidding_pb2___EnhancedCpc,
    MaximizeConversions as google___ads___googleads___v6___common___bidding_pb2___MaximizeConversions,
    MaximizeConversionValue as google___ads___googleads___v6___common___bidding_pb2___MaximizeConversionValue,
    TargetCpa as google___ads___googleads___v6___common___bidding_pb2___TargetCpa,
    TargetImpressionShare as google___ads___googleads___v6___common___bidding_pb2___TargetImpressionShare,
    TargetRoas as google___ads___googleads___v6___common___bidding_pb2___TargetRoas,
    TargetSpend as google___ads___googleads___v6___common___bidding_pb2___TargetSpend,
)
from google.ads.google_ads.v6.proto.enums.bidding_strategy_status_pb2 import (
    BiddingStrategyStatusEnum as google___ads___googleads___v6___enums___bidding_strategy_status_pb2___BiddingStrategyStatusEnum,
)
from google.ads.google_ads.v6.proto.enums.bidding_strategy_type_pb2 import (
    BiddingStrategyTypeEnum as google___ads___googleads___v6___enums___bidding_strategy_type_pb2___BiddingStrategyTypeEnum,
)

builtin___bool = bool
builtin___bytes = bytes
builtin___float = float
builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class BiddingStrategy(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    resource_name: typing___Text = ...
    id: builtin___int = ...
    name: typing___Text = ...
    status: google___ads___googleads___v6___enums___bidding_strategy_status_pb2___BiddingStrategyStatusEnum.BiddingStrategyStatusValue = ...
    type: google___ads___googleads___v6___enums___bidding_strategy_type_pb2___BiddingStrategyTypeEnum.BiddingStrategyTypeValue = ...
    effective_currency_code: typing___Text = ...
    campaign_count: builtin___int = ...
    non_removed_campaign_count: builtin___int = ...
    @property
    def enhanced_cpc(
        self,
    ) -> google___ads___googleads___v6___common___bidding_pb2___EnhancedCpc: ...
    @property
    def maximize_conversion_value(
        self,
    ) -> google___ads___googleads___v6___common___bidding_pb2___MaximizeConversionValue: ...
    @property
    def maximize_conversions(
        self,
    ) -> google___ads___googleads___v6___common___bidding_pb2___MaximizeConversions: ...
    @property
    def target_cpa(
        self,
    ) -> google___ads___googleads___v6___common___bidding_pb2___TargetCpa: ...
    @property
    def target_impression_share(
        self,
    ) -> google___ads___googleads___v6___common___bidding_pb2___TargetImpressionShare: ...
    @property
    def target_roas(
        self,
    ) -> google___ads___googleads___v6___common___bidding_pb2___TargetRoas: ...
    @property
    def target_spend(
        self,
    ) -> google___ads___googleads___v6___common___bidding_pb2___TargetSpend: ...
    def __init__(
        self,
        *,
        resource_name: typing___Optional[typing___Text] = None,
        id: typing___Optional[builtin___int] = None,
        name: typing___Optional[typing___Text] = None,
        status: typing___Optional[
            google___ads___googleads___v6___enums___bidding_strategy_status_pb2___BiddingStrategyStatusEnum.BiddingStrategyStatusValue
        ] = None,
        type: typing___Optional[
            google___ads___googleads___v6___enums___bidding_strategy_type_pb2___BiddingStrategyTypeEnum.BiddingStrategyTypeValue
        ] = None,
        effective_currency_code: typing___Optional[typing___Text] = None,
        campaign_count: typing___Optional[builtin___int] = None,
        non_removed_campaign_count: typing___Optional[builtin___int] = None,
        enhanced_cpc: typing___Optional[
            google___ads___googleads___v6___common___bidding_pb2___EnhancedCpc
        ] = None,
        maximize_conversion_value: typing___Optional[
            google___ads___googleads___v6___common___bidding_pb2___MaximizeConversionValue
        ] = None,
        maximize_conversions: typing___Optional[
            google___ads___googleads___v6___common___bidding_pb2___MaximizeConversions
        ] = None,
        target_cpa: typing___Optional[
            google___ads___googleads___v6___common___bidding_pb2___TargetCpa
        ] = None,
        target_impression_share: typing___Optional[
            google___ads___googleads___v6___common___bidding_pb2___TargetImpressionShare
        ] = None,
        target_roas: typing___Optional[
            google___ads___googleads___v6___common___bidding_pb2___TargetRoas
        ] = None,
        target_spend: typing___Optional[
            google___ads___googleads___v6___common___bidding_pb2___TargetSpend
        ] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal[
            "_campaign_count",
            b"_campaign_count",
            "_effective_currency_code",
            b"_effective_currency_code",
            "_id",
            b"_id",
            "_name",
            b"_name",
            "_non_removed_campaign_count",
            b"_non_removed_campaign_count",
            "campaign_count",
            b"campaign_count",
            "effective_currency_code",
            b"effective_currency_code",
            "enhanced_cpc",
            b"enhanced_cpc",
            "id",
            b"id",
            "maximize_conversion_value",
            b"maximize_conversion_value",
            "maximize_conversions",
            b"maximize_conversions",
            "name",
            b"name",
            "non_removed_campaign_count",
            b"non_removed_campaign_count",
            "scheme",
            b"scheme",
            "target_cpa",
            b"target_cpa",
            "target_impression_share",
            b"target_impression_share",
            "target_roas",
            b"target_roas",
            "target_spend",
            b"target_spend",
        ],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "_campaign_count",
            b"_campaign_count",
            "_effective_currency_code",
            b"_effective_currency_code",
            "_id",
            b"_id",
            "_name",
            b"_name",
            "_non_removed_campaign_count",
            b"_non_removed_campaign_count",
            "campaign_count",
            b"campaign_count",
            "effective_currency_code",
            b"effective_currency_code",
            "enhanced_cpc",
            b"enhanced_cpc",
            "id",
            b"id",
            "maximize_conversion_value",
            b"maximize_conversion_value",
            "maximize_conversions",
            b"maximize_conversions",
            "name",
            b"name",
            "non_removed_campaign_count",
            b"non_removed_campaign_count",
            "resource_name",
            b"resource_name",
            "scheme",
            b"scheme",
            "status",
            b"status",
            "target_cpa",
            b"target_cpa",
            "target_impression_share",
            b"target_impression_share",
            "target_roas",
            b"target_roas",
            "target_spend",
            b"target_spend",
            "type",
            b"type",
        ],
    ) -> None: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal["_campaign_count", b"_campaign_count"],
    ) -> typing_extensions___Literal["campaign_count"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_effective_currency_code", b"_effective_currency_code"
        ],
    ) -> typing_extensions___Literal["effective_currency_code"]: ...
    @typing___overload
    def WhichOneof(
        self, oneof_group: typing_extensions___Literal["_id", b"_id"]
    ) -> typing_extensions___Literal["id"]: ...
    @typing___overload
    def WhichOneof(
        self, oneof_group: typing_extensions___Literal["_name", b"_name"]
    ) -> typing_extensions___Literal["name"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_non_removed_campaign_count", b"_non_removed_campaign_count"
        ],
    ) -> typing_extensions___Literal["non_removed_campaign_count"]: ...
    @typing___overload
    def WhichOneof(
        self, oneof_group: typing_extensions___Literal["scheme", b"scheme"]
    ) -> typing_extensions___Literal[
        "enhanced_cpc",
        "maximize_conversion_value",
        "maximize_conversions",
        "target_cpa",
        "target_impression_share",
        "target_roas",
        "target_spend",
    ]: ...

type___BiddingStrategy = BiddingStrategy



# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import (
    Iterable as typing___Iterable,
    Optional as typing___Optional,
    Text as typing___Text,
)

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.containers import (
    RepeatedCompositeFieldContainer as google___protobuf___internal___containers___RepeatedCompositeFieldContainer,
)
from google.protobuf.message import Message as google___protobuf___message___Message
from google.protobuf.wrappers_pb2 import (
    StringValue as google___protobuf___wrappers_pb2___StringValue,
)
from typing_extensions import Literal as typing_extensions___Literal

from google.ads.google_ads.v4.proto.common.keyword_plan_common_pb2 import (
    KeywordPlanHistoricalMetrics as google___ads___googleads___v4___common___keyword_plan_common_pb2___KeywordPlanHistoricalMetrics,
)
from google.ads.google_ads.v4.proto.enums.keyword_plan_network_pb2 import (
    KeywordPlanNetworkEnum as google___ads___googleads___v4___enums___keyword_plan_network_pb2___KeywordPlanNetworkEnum,
)

builtin___bool = bool
builtin___bytes = bytes
builtin___float = float
builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class GenerateKeywordIdeasRequest(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    customer_id: typing___Text = ...
    include_adult_keywords: builtin___bool = ...
    page_token: typing___Text = ...
    page_size: builtin___int = ...
    keyword_plan_network: google___ads___googleads___v4___enums___keyword_plan_network_pb2___KeywordPlanNetworkEnum.KeywordPlanNetworkValue = ...
    @property
    def language(self) -> google___protobuf___wrappers_pb2___StringValue: ...
    @property
    def geo_target_constants(
        self,
    ) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[
        google___protobuf___wrappers_pb2___StringValue
    ]: ...
    @property
    def keyword_and_url_seed(self) -> type___KeywordAndUrlSeed: ...
    @property
    def keyword_seed(self) -> type___KeywordSeed: ...
    @property
    def url_seed(self) -> type___UrlSeed: ...
    @property
    def site_seed(self) -> type___SiteSeed: ...
    def __init__(
        self,
        *,
        customer_id: typing___Optional[typing___Text] = None,
        language: typing___Optional[
            google___protobuf___wrappers_pb2___StringValue
        ] = None,
        geo_target_constants: typing___Optional[
            typing___Iterable[google___protobuf___wrappers_pb2___StringValue]
        ] = None,
        include_adult_keywords: typing___Optional[builtin___bool] = None,
        page_token: typing___Optional[typing___Text] = None,
        page_size: typing___Optional[builtin___int] = None,
        keyword_plan_network: typing___Optional[
            google___ads___googleads___v4___enums___keyword_plan_network_pb2___KeywordPlanNetworkEnum.KeywordPlanNetworkValue
        ] = None,
        keyword_and_url_seed: typing___Optional[type___KeywordAndUrlSeed] = None,
        keyword_seed: typing___Optional[type___KeywordSeed] = None,
        url_seed: typing___Optional[type___UrlSeed] = None,
        site_seed: typing___Optional[type___SiteSeed] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal[
            "keyword_and_url_seed",
            b"keyword_and_url_seed",
            "keyword_seed",
            b"keyword_seed",
            "language",
            b"language",
            "seed",
            b"seed",
            "site_seed",
            b"site_seed",
            "url_seed",
            b"url_seed",
        ],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "customer_id",
            b"customer_id",
            "geo_target_constants",
            b"geo_target_constants",
            "include_adult_keywords",
            b"include_adult_keywords",
            "keyword_and_url_seed",
            b"keyword_and_url_seed",
            "keyword_plan_network",
            b"keyword_plan_network",
            "keyword_seed",
            b"keyword_seed",
            "language",
            b"language",
            "page_size",
            b"page_size",
            "page_token",
            b"page_token",
            "seed",
            b"seed",
            "site_seed",
            b"site_seed",
            "url_seed",
            b"url_seed",
        ],
    ) -> None: ...
    def WhichOneof(
        self, oneof_group: typing_extensions___Literal["seed", b"seed"]
    ) -> typing_extensions___Literal[
        "keyword_and_url_seed", "keyword_seed", "url_seed", "site_seed"
    ]: ...

type___GenerateKeywordIdeasRequest = GenerateKeywordIdeasRequest

class KeywordAndUrlSeed(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    @property
    def url(self) -> google___protobuf___wrappers_pb2___StringValue: ...
    @property
    def keywords(
        self,
    ) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[
        google___protobuf___wrappers_pb2___StringValue
    ]: ...
    def __init__(
        self,
        *,
        url: typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        keywords: typing___Optional[
            typing___Iterable[google___protobuf___wrappers_pb2___StringValue]
        ] = None,
    ) -> None: ...
    def HasField(
        self, field_name: typing_extensions___Literal["url", b"url"]
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal["keywords", b"keywords", "url", b"url"],
    ) -> None: ...

type___KeywordAndUrlSeed = KeywordAndUrlSeed

class KeywordSeed(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    @property
    def keywords(
        self,
    ) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[
        google___protobuf___wrappers_pb2___StringValue
    ]: ...
    def __init__(
        self,
        *,
        keywords: typing___Optional[
            typing___Iterable[google___protobuf___wrappers_pb2___StringValue]
        ] = None,
    ) -> None: ...
    def ClearField(
        self, field_name: typing_extensions___Literal["keywords", b"keywords"]
    ) -> None: ...

type___KeywordSeed = KeywordSeed

class SiteSeed(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    @property
    def site(self) -> google___protobuf___wrappers_pb2___StringValue: ...
    def __init__(
        self,
        *,
        site: typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
    ) -> None: ...
    def HasField(
        self, field_name: typing_extensions___Literal["site", b"site"]
    ) -> builtin___bool: ...
    def ClearField(
        self, field_name: typing_extensions___Literal["site", b"site"]
    ) -> None: ...

type___SiteSeed = SiteSeed

class UrlSeed(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    @property
    def url(self) -> google___protobuf___wrappers_pb2___StringValue: ...
    def __init__(
        self,
        *,
        url: typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
    ) -> None: ...
    def HasField(
        self, field_name: typing_extensions___Literal["url", b"url"]
    ) -> builtin___bool: ...
    def ClearField(
        self, field_name: typing_extensions___Literal["url", b"url"]
    ) -> None: ...

type___UrlSeed = UrlSeed

class GenerateKeywordIdeaResponse(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    next_page_token: typing___Text = ...
    total_size: builtin___int = ...
    @property
    def results(
        self,
    ) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[
        type___GenerateKeywordIdeaResult
    ]: ...
    def __init__(
        self,
        *,
        results: typing___Optional[
            typing___Iterable[type___GenerateKeywordIdeaResult]
        ] = None,
        next_page_token: typing___Optional[typing___Text] = None,
        total_size: typing___Optional[builtin___int] = None,
    ) -> None: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "next_page_token",
            b"next_page_token",
            "results",
            b"results",
            "total_size",
            b"total_size",
        ],
    ) -> None: ...

type___GenerateKeywordIdeaResponse = GenerateKeywordIdeaResponse

class GenerateKeywordIdeaResult(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    @property
    def text(self) -> google___protobuf___wrappers_pb2___StringValue: ...
    @property
    def keyword_idea_metrics(
        self,
    ) -> google___ads___googleads___v4___common___keyword_plan_common_pb2___KeywordPlanHistoricalMetrics: ...
    def __init__(
        self,
        *,
        text: typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        keyword_idea_metrics: typing___Optional[
            google___ads___googleads___v4___common___keyword_plan_common_pb2___KeywordPlanHistoricalMetrics
        ] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal[
            "keyword_idea_metrics", b"keyword_idea_metrics", "text", b"text"
        ],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "keyword_idea_metrics", b"keyword_idea_metrics", "text", b"text"
        ],
    ) -> None: ...

type___GenerateKeywordIdeaResult = GenerateKeywordIdeaResult



# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import (
    Optional as typing___Optional,
    Text as typing___Text,
    overload as typing___overload,
)

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.message import Message as google___protobuf___message___Message
from typing_extensions import Literal as typing_extensions___Literal

from google.ads.google_ads.v6.proto.common.criteria_pb2 import (
    KeywordInfo as google___ads___googleads___v6___common___criteria_pb2___KeywordInfo,
    MobileAppCategoryInfo as google___ads___googleads___v6___common___criteria_pb2___MobileAppCategoryInfo,
    MobileApplicationInfo as google___ads___googleads___v6___common___criteria_pb2___MobileApplicationInfo,
    PlacementInfo as google___ads___googleads___v6___common___criteria_pb2___PlacementInfo,
    YouTubeChannelInfo as google___ads___googleads___v6___common___criteria_pb2___YouTubeChannelInfo,
    YouTubeVideoInfo as google___ads___googleads___v6___common___criteria_pb2___YouTubeVideoInfo,
)
from google.ads.google_ads.v6.proto.enums.criterion_type_pb2 import (
    CriterionTypeEnum as google___ads___googleads___v6___enums___criterion_type_pb2___CriterionTypeEnum,
)

builtin___bool = bool
builtin___bytes = bytes
builtin___float = float
builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class SharedCriterion(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    resource_name: typing___Text = ...
    shared_set: typing___Text = ...
    criterion_id: builtin___int = ...
    type: google___ads___googleads___v6___enums___criterion_type_pb2___CriterionTypeEnum.CriterionTypeValue = ...
    @property
    def keyword(
        self,
    ) -> google___ads___googleads___v6___common___criteria_pb2___KeywordInfo: ...
    @property
    def youtube_video(
        self,
    ) -> google___ads___googleads___v6___common___criteria_pb2___YouTubeVideoInfo: ...
    @property
    def youtube_channel(
        self,
    ) -> google___ads___googleads___v6___common___criteria_pb2___YouTubeChannelInfo: ...
    @property
    def placement(
        self,
    ) -> google___ads___googleads___v6___common___criteria_pb2___PlacementInfo: ...
    @property
    def mobile_app_category(
        self,
    ) -> google___ads___googleads___v6___common___criteria_pb2___MobileAppCategoryInfo: ...
    @property
    def mobile_application(
        self,
    ) -> google___ads___googleads___v6___common___criteria_pb2___MobileApplicationInfo: ...
    def __init__(
        self,
        *,
        resource_name: typing___Optional[typing___Text] = None,
        shared_set: typing___Optional[typing___Text] = None,
        criterion_id: typing___Optional[builtin___int] = None,
        type: typing___Optional[
            google___ads___googleads___v6___enums___criterion_type_pb2___CriterionTypeEnum.CriterionTypeValue
        ] = None,
        keyword: typing___Optional[
            google___ads___googleads___v6___common___criteria_pb2___KeywordInfo
        ] = None,
        youtube_video: typing___Optional[
            google___ads___googleads___v6___common___criteria_pb2___YouTubeVideoInfo
        ] = None,
        youtube_channel: typing___Optional[
            google___ads___googleads___v6___common___criteria_pb2___YouTubeChannelInfo
        ] = None,
        placement: typing___Optional[
            google___ads___googleads___v6___common___criteria_pb2___PlacementInfo
        ] = None,
        mobile_app_category: typing___Optional[
            google___ads___googleads___v6___common___criteria_pb2___MobileAppCategoryInfo
        ] = None,
        mobile_application: typing___Optional[
            google___ads___googleads___v6___common___criteria_pb2___MobileApplicationInfo
        ] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal[
            "_criterion_id",
            b"_criterion_id",
            "_shared_set",
            b"_shared_set",
            "criterion",
            b"criterion",
            "criterion_id",
            b"criterion_id",
            "keyword",
            b"keyword",
            "mobile_app_category",
            b"mobile_app_category",
            "mobile_application",
            b"mobile_application",
            "placement",
            b"placement",
            "shared_set",
            b"shared_set",
            "youtube_channel",
            b"youtube_channel",
            "youtube_video",
            b"youtube_video",
        ],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "_criterion_id",
            b"_criterion_id",
            "_shared_set",
            b"_shared_set",
            "criterion",
            b"criterion",
            "criterion_id",
            b"criterion_id",
            "keyword",
            b"keyword",
            "mobile_app_category",
            b"mobile_app_category",
            "mobile_application",
            b"mobile_application",
            "placement",
            b"placement",
            "resource_name",
            b"resource_name",
            "shared_set",
            b"shared_set",
            "type",
            b"type",
            "youtube_channel",
            b"youtube_channel",
            "youtube_video",
            b"youtube_video",
        ],
    ) -> None: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal["_criterion_id", b"_criterion_id"],
    ) -> typing_extensions___Literal["criterion_id"]: ...
    @typing___overload
    def WhichOneof(
        self, oneof_group: typing_extensions___Literal["_shared_set", b"_shared_set"]
    ) -> typing_extensions___Literal["shared_set"]: ...
    @typing___overload
    def WhichOneof(
        self, oneof_group: typing_extensions___Literal["criterion", b"criterion"]
    ) -> typing_extensions___Literal[
        "keyword",
        "youtube_video",
        "youtube_channel",
        "placement",
        "mobile_app_category",
        "mobile_application",
    ]: ...

type___SharedCriterion = SharedCriterion



# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import NewType as typing___NewType, cast as typing___cast

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.enum_type_wrapper import (
    _EnumTypeWrapper as google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper,
)
from google.protobuf.message import Message as google___protobuf___message___Message

builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class FeedItemTargetDeviceEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    FeedItemTargetDeviceValue = typing___NewType(
        "FeedItemTargetDeviceValue", builtin___int
    )
    type___FeedItemTargetDeviceValue = FeedItemTargetDeviceValue
    FeedItemTargetDevice: _FeedItemTargetDevice
    class _FeedItemTargetDevice(
        google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[
            FeedItemTargetDeviceEnum.FeedItemTargetDeviceValue
        ]
    ):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        UNSPECIFIED = typing___cast(
            FeedItemTargetDeviceEnum.FeedItemTargetDeviceValue, 0
        )
        UNKNOWN = typing___cast(FeedItemTargetDeviceEnum.FeedItemTargetDeviceValue, 1)
        MOBILE = typing___cast(FeedItemTargetDeviceEnum.FeedItemTargetDeviceValue, 2)
    UNSPECIFIED = typing___cast(FeedItemTargetDeviceEnum.FeedItemTargetDeviceValue, 0)
    UNKNOWN = typing___cast(FeedItemTargetDeviceEnum.FeedItemTargetDeviceValue, 1)
    MOBILE = typing___cast(FeedItemTargetDeviceEnum.FeedItemTargetDeviceValue, 2)
    type___FeedItemTargetDevice = FeedItemTargetDevice
    def __init__(self,) -> None: ...

type___FeedItemTargetDeviceEnum = FeedItemTargetDeviceEnum



# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import NewType as typing___NewType, cast as typing___cast

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.enum_type_wrapper import (
    _EnumTypeWrapper as google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper,
)
from google.protobuf.message import Message as google___protobuf___message___Message

builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class ConversionActionCategoryEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    ConversionActionCategoryValue = typing___NewType(
        "ConversionActionCategoryValue", builtin___int
    )
    type___ConversionActionCategoryValue = ConversionActionCategoryValue
    ConversionActionCategory: _ConversionActionCategory
    class _ConversionActionCategory(
        google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[
            ConversionActionCategoryEnum.ConversionActionCategoryValue
        ]
    ):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        UNSPECIFIED = typing___cast(
            ConversionActionCategoryEnum.ConversionActionCategoryValue, 0
        )
        UNKNOWN = typing___cast(
            ConversionActionCategoryEnum.ConversionActionCategoryValue, 1
        )
        DEFAULT = typing___cast(
            ConversionActionCategoryEnum.ConversionActionCategoryValue, 2
        )
        PAGE_VIEW = typing___cast(
            ConversionActionCategoryEnum.ConversionActionCategoryValue, 3
        )
        PURCHASE = typing___cast(
            ConversionActionCategoryEnum.ConversionActionCategoryValue, 4
        )
        SIGNUP = typing___cast(
            ConversionActionCategoryEnum.ConversionActionCategoryValue, 5
        )
        LEAD = typing___cast(
            ConversionActionCategoryEnum.ConversionActionCategoryValue, 6
        )
        DOWNLOAD = typing___cast(
            ConversionActionCategoryEnum.ConversionActionCategoryValue, 7
        )
        ADD_TO_CART = typing___cast(
            ConversionActionCategoryEnum.ConversionActionCategoryValue, 8
        )
        BEGIN_CHECKOUT = typing___cast(
            ConversionActionCategoryEnum.ConversionActionCategoryValue, 9
        )
        SUBSCRIBE_PAID = typing___cast(
            ConversionActionCategoryEnum.ConversionActionCategoryValue, 10
        )
        PHONE_CALL_LEAD = typing___cast(
            ConversionActionCategoryEnum.ConversionActionCategoryValue, 11
        )
        IMPORTED_LEAD = typing___cast(
            ConversionActionCategoryEnum.ConversionActionCategoryValue, 12
        )
        SUBMIT_LEAD_FORM = typing___cast(
            ConversionActionCategoryEnum.ConversionActionCategoryValue, 13
        )
        BOOK_APPOINTMENT = typing___cast(
            ConversionActionCategoryEnum.ConversionActionCategoryValue, 14
        )
        REQUEST_QUOTE = typing___cast(
            ConversionActionCategoryEnum.ConversionActionCategoryValue, 15
        )
        GET_DIRECTIONS = typing___cast(
            ConversionActionCategoryEnum.ConversionActionCategoryValue, 16
        )
        OUTBOUND_CLICK = typing___cast(
            ConversionActionCategoryEnum.ConversionActionCategoryValue, 17
        )
        CONTACT = typing___cast(
            ConversionActionCategoryEnum.ConversionActionCategoryValue, 18
        )
        ENGAGEMENT = typing___cast(
            ConversionActionCategoryEnum.ConversionActionCategoryValue, 19
        )
        STORE_VISIT = typing___cast(
            ConversionActionCategoryEnum.ConversionActionCategoryValue, 20
        )
        STORE_SALE = typing___cast(
            ConversionActionCategoryEnum.ConversionActionCategoryValue, 21
        )
    UNSPECIFIED = typing___cast(
        ConversionActionCategoryEnum.ConversionActionCategoryValue, 0
    )
    UNKNOWN = typing___cast(
        ConversionActionCategoryEnum.ConversionActionCategoryValue, 1
    )
    DEFAULT = typing___cast(
        ConversionActionCategoryEnum.ConversionActionCategoryValue, 2
    )
    PAGE_VIEW = typing___cast(
        ConversionActionCategoryEnum.ConversionActionCategoryValue, 3
    )
    PURCHASE = typing___cast(
        ConversionActionCategoryEnum.ConversionActionCategoryValue, 4
    )
    SIGNUP = typing___cast(
        ConversionActionCategoryEnum.ConversionActionCategoryValue, 5
    )
    LEAD = typing___cast(ConversionActionCategoryEnum.ConversionActionCategoryValue, 6)
    DOWNLOAD = typing___cast(
        ConversionActionCategoryEnum.ConversionActionCategoryValue, 7
    )
    ADD_TO_CART = typing___cast(
        ConversionActionCategoryEnum.ConversionActionCategoryValue, 8
    )
    BEGIN_CHECKOUT = typing___cast(
        ConversionActionCategoryEnum.ConversionActionCategoryValue, 9
    )
    SUBSCRIBE_PAID = typing___cast(
        ConversionActionCategoryEnum.ConversionActionCategoryValue, 10
    )
    PHONE_CALL_LEAD = typing___cast(
        ConversionActionCategoryEnum.ConversionActionCategoryValue, 11
    )
    IMPORTED_LEAD = typing___cast(
        ConversionActionCategoryEnum.ConversionActionCategoryValue, 12
    )
    SUBMIT_LEAD_FORM = typing___cast(
        ConversionActionCategoryEnum.ConversionActionCategoryValue, 13
    )
    BOOK_APPOINTMENT = typing___cast(
        ConversionActionCategoryEnum.ConversionActionCategoryValue, 14
    )
    REQUEST_QUOTE = typing___cast(
        ConversionActionCategoryEnum.ConversionActionCategoryValue, 15
    )
    GET_DIRECTIONS = typing___cast(
        ConversionActionCategoryEnum.ConversionActionCategoryValue, 16
    )
    OUTBOUND_CLICK = typing___cast(
        ConversionActionCategoryEnum.ConversionActionCategoryValue, 17
    )
    CONTACT = typing___cast(
        ConversionActionCategoryEnum.ConversionActionCategoryValue, 18
    )
    ENGAGEMENT = typing___cast(
        ConversionActionCategoryEnum.ConversionActionCategoryValue, 19
    )
    STORE_VISIT = typing___cast(
        ConversionActionCategoryEnum.ConversionActionCategoryValue, 20
    )
    STORE_SALE = typing___cast(
        ConversionActionCategoryEnum.ConversionActionCategoryValue, 21
    )
    type___ConversionActionCategory = ConversionActionCategory
    def __init__(self,) -> None: ...

type___ConversionActionCategoryEnum = ConversionActionCategoryEnum



# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import NewType as typing___NewType, cast as typing___cast

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.enum_type_wrapper import (
    _EnumTypeWrapper as google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper,
)
from google.protobuf.message import Message as google___protobuf___message___Message

builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class ThirdPartyAppAnalyticsLinkErrorEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    ThirdPartyAppAnalyticsLinkErrorValue = typing___NewType(
        "ThirdPartyAppAnalyticsLinkErrorValue", builtin___int
    )
    type___ThirdPartyAppAnalyticsLinkErrorValue = ThirdPartyAppAnalyticsLinkErrorValue
    ThirdPartyAppAnalyticsLinkError: _ThirdPartyAppAnalyticsLinkError
    class _ThirdPartyAppAnalyticsLinkError(
        google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[
            ThirdPartyAppAnalyticsLinkErrorEnum.ThirdPartyAppAnalyticsLinkErrorValue
        ]
    ):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        UNSPECIFIED = typing___cast(
            ThirdPartyAppAnalyticsLinkErrorEnum.ThirdPartyAppAnalyticsLinkErrorValue, 0
        )
        UNKNOWN = typing___cast(
            ThirdPartyAppAnalyticsLinkErrorEnum.ThirdPartyAppAnalyticsLinkErrorValue, 1
        )
        INVALID_ANALYTICS_PROVIDER_ID = typing___cast(
            ThirdPartyAppAnalyticsLinkErrorEnum.ThirdPartyAppAnalyticsLinkErrorValue, 2
        )
        INVALID_MOBILE_APP_ID = typing___cast(
            ThirdPartyAppAnalyticsLinkErrorEnum.ThirdPartyAppAnalyticsLinkErrorValue, 3
        )
        MOBILE_APP_IS_NOT_ENABLED = typing___cast(
            ThirdPartyAppAnalyticsLinkErrorEnum.ThirdPartyAppAnalyticsLinkErrorValue, 4
        )
        CANNOT_REGENERATE_SHAREABLE_LINK_ID_FOR_REMOVED_LINK = typing___cast(
            ThirdPartyAppAnalyticsLinkErrorEnum.ThirdPartyAppAnalyticsLinkErrorValue, 5
        )
    UNSPECIFIED = typing___cast(
        ThirdPartyAppAnalyticsLinkErrorEnum.ThirdPartyAppAnalyticsLinkErrorValue, 0
    )
    UNKNOWN = typing___cast(
        ThirdPartyAppAnalyticsLinkErrorEnum.ThirdPartyAppAnalyticsLinkErrorValue, 1
    )
    INVALID_ANALYTICS_PROVIDER_ID = typing___cast(
        ThirdPartyAppAnalyticsLinkErrorEnum.ThirdPartyAppAnalyticsLinkErrorValue, 2
    )
    INVALID_MOBILE_APP_ID = typing___cast(
        ThirdPartyAppAnalyticsLinkErrorEnum.ThirdPartyAppAnalyticsLinkErrorValue, 3
    )
    MOBILE_APP_IS_NOT_ENABLED = typing___cast(
        ThirdPartyAppAnalyticsLinkErrorEnum.ThirdPartyAppAnalyticsLinkErrorValue, 4
    )
    CANNOT_REGENERATE_SHAREABLE_LINK_ID_FOR_REMOVED_LINK = typing___cast(
        ThirdPartyAppAnalyticsLinkErrorEnum.ThirdPartyAppAnalyticsLinkErrorValue, 5
    )
    type___ThirdPartyAppAnalyticsLinkError = ThirdPartyAppAnalyticsLinkError
    def __init__(self,) -> None: ...

type___ThirdPartyAppAnalyticsLinkErrorEnum = ThirdPartyAppAnalyticsLinkErrorEnum



# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import NewType as typing___NewType, cast as typing___cast

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.enum_type_wrapper import (
    _EnumTypeWrapper as google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper,
)
from google.protobuf.message import Message as google___protobuf___message___Message

builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class AssetErrorEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    AssetErrorValue = typing___NewType("AssetErrorValue", builtin___int)
    type___AssetErrorValue = AssetErrorValue
    AssetError: _AssetError
    class _AssetError(
        google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[
            AssetErrorEnum.AssetErrorValue
        ]
    ):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        UNSPECIFIED = typing___cast(AssetErrorEnum.AssetErrorValue, 0)
        UNKNOWN = typing___cast(AssetErrorEnum.AssetErrorValue, 1)
        CUSTOMER_NOT_WHITELISTED_FOR_ASSET_TYPE = typing___cast(
            AssetErrorEnum.AssetErrorValue, 2
        )
        DUPLICATE_ASSET = typing___cast(AssetErrorEnum.AssetErrorValue, 3)
        DUPLICATE_ASSET_NAME = typing___cast(AssetErrorEnum.AssetErrorValue, 4)
        ASSET_DATA_IS_MISSING = typing___cast(AssetErrorEnum.AssetErrorValue, 5)
        CANNOT_MODIFY_ASSET_NAME = typing___cast(AssetErrorEnum.AssetErrorValue, 6)
    UNSPECIFIED = typing___cast(AssetErrorEnum.AssetErrorValue, 0)
    UNKNOWN = typing___cast(AssetErrorEnum.AssetErrorValue, 1)
    CUSTOMER_NOT_WHITELISTED_FOR_ASSET_TYPE = typing___cast(
        AssetErrorEnum.AssetErrorValue, 2
    )
    DUPLICATE_ASSET = typing___cast(AssetErrorEnum.AssetErrorValue, 3)
    DUPLICATE_ASSET_NAME = typing___cast(AssetErrorEnum.AssetErrorValue, 4)
    ASSET_DATA_IS_MISSING = typing___cast(AssetErrorEnum.AssetErrorValue, 5)
    CANNOT_MODIFY_ASSET_NAME = typing___cast(AssetErrorEnum.AssetErrorValue, 6)
    type___AssetError = AssetError
    def __init__(self,) -> None: ...

type___AssetErrorEnum = AssetErrorEnum



from typing import Any

class LabelServiceStub:
    GetLabel: Any = ...
    MutateLabels: Any = ...
    def __init__(self, channel: Any) -> None: ...

class LabelServiceServicer:
    def GetLabel(self, request: Any, context: Any) -> None: ...
    def MutateLabels(self, request: Any, context: Any) -> None: ...

def add_LabelServiceServicer_to_server(servicer: Any, server: Any) -> None: ...



# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import NewType as typing___NewType, cast as typing___cast

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.enum_type_wrapper import (
    _EnumTypeWrapper as google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper,
)
from google.protobuf.message import Message as google___protobuf___message___Message

builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class CriterionCategoryChannelAvailabilityModeEnum(
    google___protobuf___message___Message
):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    CriterionCategoryChannelAvailabilityModeValue = typing___NewType(
        "CriterionCategoryChannelAvailabilityModeValue", builtin___int
    )
    type___CriterionCategoryChannelAvailabilityModeValue = (
        CriterionCategoryChannelAvailabilityModeValue
    )
    CriterionCategoryChannelAvailabilityMode: _CriterionCategoryChannelAvailabilityMode
    class _CriterionCategoryChannelAvailabilityMode(
        google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[
            CriterionCategoryChannelAvailabilityModeEnum.CriterionCategoryChannelAvailabilityModeValue
        ]
    ):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        UNSPECIFIED = typing___cast(
            CriterionCategoryChannelAvailabilityModeEnum.CriterionCategoryChannelAvailabilityModeValue,
            0,
        )
        UNKNOWN = typing___cast(
            CriterionCategoryChannelAvailabilityModeEnum.CriterionCategoryChannelAvailabilityModeValue,
            1,
        )
        ALL_CHANNELS = typing___cast(
            CriterionCategoryChannelAvailabilityModeEnum.CriterionCategoryChannelAvailabilityModeValue,
            2,
        )
        CHANNEL_TYPE_AND_ALL_SUBTYPES = typing___cast(
            CriterionCategoryChannelAvailabilityModeEnum.CriterionCategoryChannelAvailabilityModeValue,
            3,
        )
        CHANNEL_TYPE_AND_SUBSET_SUBTYPES = typing___cast(
            CriterionCategoryChannelAvailabilityModeEnum.CriterionCategoryChannelAvailabilityModeValue,
            4,
        )
    UNSPECIFIED = typing___cast(
        CriterionCategoryChannelAvailabilityModeEnum.CriterionCategoryChannelAvailabilityModeValue,
        0,
    )
    UNKNOWN = typing___cast(
        CriterionCategoryChannelAvailabilityModeEnum.CriterionCategoryChannelAvailabilityModeValue,
        1,
    )
    ALL_CHANNELS = typing___cast(
        CriterionCategoryChannelAvailabilityModeEnum.CriterionCategoryChannelAvailabilityModeValue,
        2,
    )
    CHANNEL_TYPE_AND_ALL_SUBTYPES = typing___cast(
        CriterionCategoryChannelAvailabilityModeEnum.CriterionCategoryChannelAvailabilityModeValue,
        3,
    )
    CHANNEL_TYPE_AND_SUBSET_SUBTYPES = typing___cast(
        CriterionCategoryChannelAvailabilityModeEnum.CriterionCategoryChannelAvailabilityModeValue,
        4,
    )
    type___CriterionCategoryChannelAvailabilityMode = (
        CriterionCategoryChannelAvailabilityMode
    )
    def __init__(self,) -> None: ...

type___CriterionCategoryChannelAvailabilityModeEnum = (
    CriterionCategoryChannelAvailabilityModeEnum
)



# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import NewType as typing___NewType, cast as typing___cast

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.enum_type_wrapper import (
    _EnumTypeWrapper as google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper,
)
from google.protobuf.message import Message as google___protobuf___message___Message

builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class EducationPlaceholderFieldEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    EducationPlaceholderFieldValue = typing___NewType(
        "EducationPlaceholderFieldValue", builtin___int
    )
    type___EducationPlaceholderFieldValue = EducationPlaceholderFieldValue
    EducationPlaceholderField: _EducationPlaceholderField
    class _EducationPlaceholderField(
        google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[
            EducationPlaceholderFieldEnum.EducationPlaceholderFieldValue
        ]
    ):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        UNSPECIFIED = typing___cast(
            EducationPlaceholderFieldEnum.EducationPlaceholderFieldValue, 0
        )
        UNKNOWN = typing___cast(
            EducationPlaceholderFieldEnum.EducationPlaceholderFieldValue, 1
        )
        PROGRAM_ID = typing___cast(
            EducationPlaceholderFieldEnum.EducationPlaceholderFieldValue, 2
        )
        LOCATION_ID = typing___cast(
            EducationPlaceholderFieldEnum.EducationPlaceholderFieldValue, 3
        )
        PROGRAM_NAME = typing___cast(
            EducationPlaceholderFieldEnum.EducationPlaceholderFieldValue, 4
        )
        AREA_OF_STUDY = typing___cast(
            EducationPlaceholderFieldEnum.EducationPlaceholderFieldValue, 5
        )
        PROGRAM_DESCRIPTION = typing___cast(
            EducationPlaceholderFieldEnum.EducationPlaceholderFieldValue, 6
        )
        SCHOOL_NAME = typing___cast(
            EducationPlaceholderFieldEnum.EducationPlaceholderFieldValue, 7
        )
        ADDRESS = typing___cast(
            EducationPlaceholderFieldEnum.EducationPlaceholderFieldValue, 8
        )
        THUMBNAIL_IMAGE_URL = typing___cast(
            EducationPlaceholderFieldEnum.EducationPlaceholderFieldValue, 9
        )
        ALTERNATIVE_THUMBNAIL_IMAGE_URL = typing___cast(
            EducationPlaceholderFieldEnum.EducationPlaceholderFieldValue, 10
        )
        FINAL_URLS = typing___cast(
            EducationPlaceholderFieldEnum.EducationPlaceholderFieldValue, 11
        )
        FINAL_MOBILE_URLS = typing___cast(
            EducationPlaceholderFieldEnum.EducationPlaceholderFieldValue, 12
        )
        TRACKING_URL = typing___cast(
            EducationPlaceholderFieldEnum.EducationPlaceholderFieldValue, 13
        )
        CONTEXTUAL_KEYWORDS = typing___cast(
            EducationPlaceholderFieldEnum.EducationPlaceholderFieldValue, 14
        )
        ANDROID_APP_LINK = typing___cast(
            EducationPlaceholderFieldEnum.EducationPlaceholderFieldValue, 15
        )
        SIMILAR_PROGRAM_IDS = typing___cast(
            EducationPlaceholderFieldEnum.EducationPlaceholderFieldValue, 16
        )
        IOS_APP_LINK = typing___cast(
            EducationPlaceholderFieldEnum.EducationPlaceholderFieldValue, 17
        )
        IOS_APP_STORE_ID = typing___cast(
            EducationPlaceholderFieldEnum.EducationPlaceholderFieldValue, 18
        )
    UNSPECIFIED = typing___cast(
        EducationPlaceholderFieldEnum.EducationPlaceholderFieldValue, 0
    )
    UNKNOWN = typing___cast(
        EducationPlaceholderFieldEnum.EducationPlaceholderFieldValue, 1
    )
    PROGRAM_ID = typing___cast(
        EducationPlaceholderFieldEnum.EducationPlaceholderFieldValue, 2
    )
    LOCATION_ID = typing___cast(
        EducationPlaceholderFieldEnum.EducationPlaceholderFieldValue, 3
    )
    PROGRAM_NAME = typing___cast(
        EducationPlaceholderFieldEnum.EducationPlaceholderFieldValue, 4
    )
    AREA_OF_STUDY = typing___cast(
        EducationPlaceholderFieldEnum.EducationPlaceholderFieldValue, 5
    )
    PROGRAM_DESCRIPTION = typing___cast(
        EducationPlaceholderFieldEnum.EducationPlaceholderFieldValue, 6
    )
    SCHOOL_NAME = typing___cast(
        EducationPlaceholderFieldEnum.EducationPlaceholderFieldValue, 7
    )
    ADDRESS = typing___cast(
        EducationPlaceholderFieldEnum.EducationPlaceholderFieldValue, 8
    )
    THUMBNAIL_IMAGE_URL = typing___cast(
        EducationPlaceholderFieldEnum.EducationPlaceholderFieldValue, 9
    )
    ALTERNATIVE_THUMBNAIL_IMAGE_URL = typing___cast(
        EducationPlaceholderFieldEnum.EducationPlaceholderFieldValue, 10
    )
    FINAL_URLS = typing___cast(
        EducationPlaceholderFieldEnum.EducationPlaceholderFieldValue, 11
    )
    FINAL_MOBILE_URLS = typing___cast(
        EducationPlaceholderFieldEnum.EducationPlaceholderFieldValue, 12
    )
    TRACKING_URL = typing___cast(
        EducationPlaceholderFieldEnum.EducationPlaceholderFieldValue, 13
    )
    CONTEXTUAL_KEYWORDS = typing___cast(
        EducationPlaceholderFieldEnum.EducationPlaceholderFieldValue, 14
    )
    ANDROID_APP_LINK = typing___cast(
        EducationPlaceholderFieldEnum.EducationPlaceholderFieldValue, 15
    )
    SIMILAR_PROGRAM_IDS = typing___cast(
        EducationPlaceholderFieldEnum.EducationPlaceholderFieldValue, 16
    )
    IOS_APP_LINK = typing___cast(
        EducationPlaceholderFieldEnum.EducationPlaceholderFieldValue, 17
    )
    IOS_APP_STORE_ID = typing___cast(
        EducationPlaceholderFieldEnum.EducationPlaceholderFieldValue, 18
    )
    type___EducationPlaceholderField = EducationPlaceholderField
    def __init__(self,) -> None: ...

type___EducationPlaceholderFieldEnum = EducationPlaceholderFieldEnum
